@@ -6,7 +6,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 16, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 16, 2004)
 
 This software is a computer program whose purpose is to provide basal and 
 utilitary classes. This file belongs to the Bio++ Project.
@@ -53,7 +53,7 @@ OutputStream* ApplicationTools::error   = new StdErr();
 OutputStream* ApplicationTools::message = new StdOut();
 OutputStream* ApplicationTools::warning = new StdOut();
 time_t ApplicationTools::startTime;
-unsigned int ApplicationTools::terminalWidth = 80;
+size_t ApplicationTools::terminalWidth = 80;
 float ApplicationTools::terminalSplit = 0.5;
 bool ApplicationTools::interactive = true;
 
@@ -63,7 +63,7 @@ bool ApplicationTools::parameterExists(
   const std::string & parameterName,
   std::map<std::string, std::string>& params)
 {
-  return params.find(parameterName) != params.end() && !TextTools::isEmpty(params[parameterName]);
+  return (params.find(parameterName) != params.end() && !TextTools::isEmpty(params[parameterName]));
 }
   
 /******************************************************************************/
@@ -161,43 +161,52 @@ std::string ApplicationTools::getStringParameter(
 /******************************************************************************/
 
 bool ApplicationTools::getBooleanParameter(
-  const std::string & parameterName,
-  std::map<std::string, std::string> & params,
+  const std::string& parameterName,
+  std::map<std::string, std::string>& params,
   bool defaultValue,
-  const std::string & suffix,
+  const std::string& suffix,
   bool suffixIsOptional,
   bool warn)
 {
+  string sParam;
   bool bParam = defaultValue;
-  if(parameterExists(parameterName + suffix, params))
+  if (parameterExists(parameterName + suffix, params))
   {
-    string sParam = params[parameterName + suffix];
-    bParam = (sParam == "true") 
-        || (sParam == "TRUE")
-        || (sParam == "t")
-        || (sParam == "T")
-        || (sParam == "yes")
-        || (sParam == "YES")
-        || (sParam == "y")
-        || (sParam == "Y")
-        || (sParam == "1");
+    sParam = params[parameterName + suffix];
   }
-  else if (suffixIsOptional && parameterExists(parameterName, params)) {
-    string sParam = params[parameterName];
-    bParam = (sParam == "true") 
-        || (sParam == "TRUE")
-        || (sParam == "t")
-        || (sParam == "T")
-        || (sParam == "yes")
-        || (sParam == "YES")
-        || (sParam == "y")
-        || (sParam == "Y")
-          || (sParam == "1");
-  }
-  else if (warn)
+  else if (suffixIsOptional && parameterExists(parameterName, params))
   {
-    displayWarning("Parameter " + parameterName + " not specified. Default used instead: " + TextTools::toString(defaultValue));
+    sParam = params[parameterName];
   }
+  else {
+    if (warn)
+    {
+      displayWarning("Parameter " + parameterName + " not specified. Default used instead: " + TextTools::toString(defaultValue));
+    }
+    return bParam;
+  }
+  if ((sParam == "true") 
+   || (sParam == "TRUE")
+   || (sParam == "t")
+   || (sParam == "T")
+   || (sParam == "yes")
+   || (sParam == "YES")
+   || (sParam == "y")
+   || (sParam == "Y")
+   || (sParam == "1"))
+    bParam = true;
+  else if ((sParam == "false") 
+        || (sParam == "FALSE")
+        || (sParam == "f")
+        || (sParam == "F")
+        || (sParam == "no")
+        || (sParam == "NO")
+        || (sParam == "n")
+        || (sParam == "N")
+        || (sParam == "0"))
+    bParam = false;
+  else throw Exception("ApplicationTools::getBooleanParameter. Wrong description:" + sParam);
+ 
   return bParam;
 }
 
@@ -213,9 +222,9 @@ void ApplicationTools::displayTask(const std::string& text, bool eof)
 {
   if (message)
   {
-    *message << TextTools::resizeRight(text, (unsigned int) (terminalWidth * terminalSplit - 1), '.') << ": ";
-    if(eof) message->endLine();
-    else    message->flush();
+    *message << TextTools::resizeRight(text, static_cast<size_t>(static_cast<float>(terminalWidth) * terminalSplit - 1), '.') << ": ";
+    if (eof) message->endLine();
+    else     message->flush();
   }
 }
     
@@ -227,8 +236,8 @@ void ApplicationTools::displayGauge(size_t iter, size_t total, char symbol, cons
 {
   if (!message) return;
   if (total == 0) return;//We do not display anything in that case.
-  size_t width = static_cast<size_t>(terminalWidth * terminalSplit - 2);
-  string gauge = string(static_cast<unsigned int>((1. * iter / total) * width), symbol);
+  size_t width = static_cast<size_t>(static_cast<float>(terminalWidth) * terminalSplit - 2);
+  string gauge = string(static_cast<size_t>((1. * static_cast<double>(iter) / static_cast<double>(total)) * static_cast<double>(width)), symbol);
   string info = mes;
   if (interactive)
   {
@@ -247,10 +256,10 @@ void ApplicationTools::displayGauge(size_t iter, size_t total, char symbol, cons
       message->flush();
       return;
     }
-    size_t step = static_cast<size_t>(ceil(1. * total / width));
+    size_t step = static_cast<size_t>(ceil(1. * static_cast<double>(total) / static_cast<double>(width)));
     if (iter >= total)
     {
-      size_t fill = static_cast<size_t>(terminalWidth * terminalSplit) - (total - 1) / step - 1;
+      size_t fill = static_cast<size_t>(static_cast<float>(terminalWidth) * terminalSplit) - (total - 1) / step - 1;
       *message << TextTools::resizeLeft("]", fill, symbol);
       message->flush();
       return;
