@@ -6,7 +6,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 17, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
 
 This software is a computer program whose purpose is to provide basal and 
 utilitary classes. This file belongs to the Bio++ Project.
@@ -112,7 +112,7 @@ class ApplicationTools
     /**
      * @brief The width of the output terminal (in character).
      */
-    static unsigned int terminalWidth;
+    static size_t terminalWidth;
 
     /**
      * @brief The fraction of terminal width dedicated to messages.
@@ -296,10 +296,15 @@ class ApplicationTools
     {
       std::string s = getStringParameter(parameterName, params, defaultValue, suffix, suffixIsOptional, warn);
       if (TextTools::isEmpty(s)) return std::vector<T>(0);
+      if (s[0] == '(' && s[s.size() - 1] == ')') {
+        //This is a delimited vector:
+        s = s.substr(1, s.size() - 2);
+        if (TextTools::isEmpty(s)) return std::vector<T>(0);
+      }
       NestedStringTokenizer st(s, "(", ")", TextTools::toString(separator));
-      unsigned int n = st.numberOfRemainingTokens();
+      size_t n = st.numberOfRemainingTokens();
       std::vector<T> v(n);
-      for (unsigned int i = 0; i < n; i++)
+      for (size_t i = 0; i < n; i++)
       {
         v[i] = TextTools::fromString<T>(st.nextToken());
       }
@@ -334,9 +339,9 @@ class ApplicationTools
     {
       std::string s = getStringParameter(parameterName, params, defaultValue, suffix, suffixIsOptional, warn);
       StringTokenizer st(s, TextTools::toString(separator));
-      unsigned int n = st.numberOfRemainingTokens();
+      size_t n = st.numberOfRemainingTokens();
       std::vector<T> v;
-      for (unsigned int i = 0; i < n; i++)
+      for (size_t i = 0; i < n; i++)
       {
         std::string token = st.nextToken();
         std::string::size_type pos = token.find(rangeOperator);
@@ -413,7 +418,7 @@ class ApplicationTools
     template<class T>
     static void displayResult(const std::string& text, const T& result)
     {
-      displayMessage(TextTools::resizeRight(text, (unsigned int) (terminalWidth * terminalSplit - 1), '.') + ": " + TextTools::toString<T>(result));
+      displayMessage(TextTools::resizeRight(text, static_cast<size_t>(static_cast<float>(terminalWidth) * terminalSplit - 1), '.') + ": " + TextTools::toString<T>(result));
     }
 
     /**
@@ -433,7 +438,7 @@ class ApplicationTools
      *
      * Show progress status.
      * @code
-     * for(unsigned int i = 0; i < 1000; i++)
+     * for(size_t i = 0; i < 1000; i++)
      * {
      *   ApplicationTools::displayGauge(i, 999, '*');
      *   //Perform time consuming task...
@@ -456,7 +461,7 @@ class ApplicationTools
      *
      * Show progress status.
      * @code
-     * for(unsigned int i = 0; i < 1000; i++)
+     * for(size_t i = 0; i < 1000; i++)
      * {
      *   ApplicationTools::displayUnlimitedGauge(i);
      *   //Perform time consuming task...
