@@ -43,6 +43,7 @@ knowledge of the CeCILL license and that you accept its terms.
 #define _EXCEPTIONS_H_
 
 #include <stdexcept>
+#include <vector>
 
 namespace bpp
 {
@@ -294,22 +295,12 @@ class NumberFormatException:
  * @brief Index out of bounds exception class.
  */
 class IndexOutOfBoundsException:
-  public BadIntegerException
+  public virtual Exception
 {
   protected:
-    int lowerBound_, upperBound_;
+    size_t badIndex_, lowerBound_, upperBound_;
   
   public:
-    
-    /**
-     * @brief Build a new IndexOutOfBoundsException.
-     *
-     * @param text   A message to be passed to the exception hierarchy.
-     * @param badInt The faulty integer.
-     * @param lowerBound Lower limit.
-     * @param upperBound Upper limit.
-     */
-    IndexOutOfBoundsException(const char* text, int badInt, int lowerBound, int upperBound);
 
     /**
      * @brief Build a new IndexOutOfBoundsException.
@@ -319,7 +310,7 @@ class IndexOutOfBoundsException:
      * @param lowerBound Lower limit.
      * @param upperBound Upper limit.
      */
-    IndexOutOfBoundsException(const std::string& text, int badInt, int lowerBound, int upperBound);
+    IndexOutOfBoundsException(const std::string& text, size_t badInt, size_t lowerBound, size_t upperBound);
   
     virtual ~IndexOutOfBoundsException() throw() {}
 
@@ -330,7 +321,75 @@ class IndexOutOfBoundsException:
      *
      * @return The bounds.
      */
-    int* getBounds() const;
+    std::vector<size_t> getBounds() const;
+
+    size_t getBadIndex() const { return badIndex_; }
+};
+
+
+/**
+ * @brief Wrong size exception class.
+ */
+class BadSizeException:
+  public virtual Exception
+{
+  protected:
+    size_t badSize_, correctSize_;
+  
+  public:
+    
+    /**
+     * @brief Build a new BadSizeException.
+     *
+     * @param text   A message to be passed to the exception hierarchy.
+     * @param badSize The faulty size.
+     * @param correctSize The expected size.
+     */
+    BadSizeException(const std::string& text, size_t badSize, size_t correctSize);
+  
+    virtual ~BadSizeException() throw() {}
+
+  public:
+    
+    size_t getBadSize() const { return badSize_; }
+    size_t getCorrectSize() const { return correctSize_; }
+};
+
+
+/**
+ * @brief Out of range exception class.
+ */
+class OutOfRangeException:
+  public Exception
+{
+  protected:
+    double lowerBound_, upperBound_;
+  
+  public:
+    
+    /**
+     * @brief Build a new OutOfRangeException.
+     *
+     * @param text   A message to be passed to the exception hierarchy.
+     * @param badValue The faulty value.
+     * @param lowerBound Lower limit.
+     * @param upperBound Upper limit.
+     */
+    OutOfRangeException(const std::string& text, double badValue, double lowerBound, double upperBound);
+  
+    virtual ~OutOfRangeException() throw() {}
+
+  public:
+    
+    /**
+     * @return The lower bound.
+     */
+    double getLowerBound() const { return lowerBound_; }
+
+    /**
+     * @return The upper bound.
+     */
+    double getUpperBound() const { return upperBound_; }
 };
 
 
