@@ -6,7 +6,7 @@
 //
 
 /*
-Copyright or © or Copr. CNRS, (November 19, 2004)
+Copyright or © or Copr. Bio++ Development Team, (November 19, 2004)
 
 This software is a computer program whose purpose is to provide classes
 for numerical calculus.
@@ -117,7 +117,7 @@ class AbstractParametrizable:
       return test;
     }
 
-    unsigned int getNumberOfParameters() const { return parameters_.size(); }
+    size_t getNumberOfParameters() const { return parameters_.size(); }
      
     void setNamespace(const std::string& prefix);
     
@@ -133,9 +133,10 @@ class AbstractParametrizable:
     virtual void fireParameterChanged(const ParameterList& parameters) = 0;
 
   protected:
-    void addParameter_(const Parameter& parameter)
+    void addParameter_(Parameter* parameter)
     {
-      parameters_.addParameter(parameter);
+      if (parameter)
+        parameters_.addParameter(parameter);
     }
 
     void addParameters_(const ParameterList& parameters)
@@ -143,9 +144,9 @@ class AbstractParametrizable:
       parameters_.addParameters(parameters);
     }
 
-    void deleteParameter_(unsigned int index) throw (IndexOutOfBoundsException)
+    void deleteParameter_(size_t index) throw (IndexOutOfBoundsException)
     {
-      if(index >= parameters_.size())
+      if (index >= parameters_.size())
         throw IndexOutOfBoundsException("AbstractParametrizable::deleteParameter_.", index, 0, parameters_.size() - 1);
       parameters_.deleteParameter(index);
     }
@@ -184,13 +185,13 @@ class AbstractParametrizable:
       return getParameter(name);
     }
 
-    Parameter& getParameter_(unsigned int index) throw (IndexOutOfBoundsException)
+    Parameter& getParameter_(size_t index) throw (IndexOutOfBoundsException)
     {
       if (index >= parameters_.size())
         throw IndexOutOfBoundsException("AbstractParametrizable::getParameter_.", index, 0, parameters_.size() - 1);
       return parameters_[index];
     }
-    const Parameter& getParameter_(unsigned int index) const throw (IndexOutOfBoundsException)
+    const Parameter& getParameter_(size_t index) const throw (IndexOutOfBoundsException)
     {
       if(index >= parameters_.size())
         throw IndexOutOfBoundsException("AbstractParametrizable::getParameter_.", index, 0, parameters_.size() - 1);
