@@ -5,7 +5,7 @@
 //
 
 /*
-  Copyright or © or Copr. CNRS, (November 17, 2004)
+  Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
 
   This software is a computer program whose purpose is to provide classes
   for numerical calculus.
@@ -165,6 +165,9 @@ void AbstractOptimizer::init(const ParameterList& params) throw (Exception)
   tolIsReached_ = false;
   isInitialized_ = true;
   time(&startTime_);
+  currentValue_ = function_->getValue();
+
+  profile("Step\t");
   for (unsigned int i = 0; i < parameters_.size(); i++)
   {
     profile(parameters_[i].getName() + "\t"); 
@@ -172,7 +175,7 @@ void AbstractOptimizer::init(const ParameterList& params) throw (Exception)
   profileln("Function\tTime");
 
   //Parameters must be assigned by doInit:
-  currentValue_ = function_->getValue();
+
   printPoint(parameters_, currentValue_);
   
   // Initialize the StopCondition:
@@ -209,7 +212,7 @@ double AbstractOptimizer::optimize() throw (Exception)
   tolIsReached_ = false;
   for (nbEval_ = 1; nbEval_ < nbEvalMax_ && ! tolIsReached_; nbEval_++)
   {
-    if (verbose_ > 0)
+    if (verbose_)
       ApplicationTools::displayUnlimitedGauge(nbEval_, "Optimizing... ");
     step();
   }
@@ -232,6 +235,19 @@ void AbstractOptimizer::profileln(double v)
 	
 /******************************************************************************/
 
+void AbstractOptimizer::profile(unsigned int v)
+{
+  if (profiler_) *profiler_ << v;
+}
+/******************************************************************************/
+
+void AbstractOptimizer::profileln(unsigned int v)
+{
+  if (profiler_) (*profiler_ << v).endLine();
+}
+	
+/******************************************************************************/
+
 void AbstractOptimizer::profile(const std::string& s)
 {
   if (profiler_) *profiler_ << s;
@@ -248,10 +264,10 @@ void AbstractOptimizer::profileln(const std::string& s)
 
 void AbstractOptimizer::printPoint(const ParameterList& params, double value)
 {
-  unsigned int ndim = params.size();
+  size_t ndim = params.size();
   profile(nbEval_);
   profile("\t");
-  for (unsigned int j = 0; j < ndim; j++)
+  for (size_t j = 0; j < ndim; j++)
   {
     profile(TextTools::toString(params[j].getValue()));
     profile("\t"); 
