@@ -104,12 +104,12 @@ void GoldenSectionSearch::doInit(const ParameterList& params) throw (Exception)
     // Make x0 to x1 the smaller segment,
     x1 = bracket.b.x;
     // and fill in the new point to be tried.
-    x2 = bracket.b.x + NumConstants::GOLDEN_RATIO_C * (bracket.c.x - bracket.b.x);
+    x2 = bracket.b.x + NumConstants::GOLDEN_RATIO_C() * (bracket.c.x - bracket.b.x);
   }
   else
   {
     x2 = bracket.b.x;
-    x1 = bracket.b.x - NumConstants::GOLDEN_RATIO_C * (bracket.b.x - bracket.a.x);
+    x1 = bracket.b.x - NumConstants::GOLDEN_RATIO_C() * (bracket.b.x - bracket.a.x);
   }
   // The initial function evaluations.
   // Note that we never need to evaluate the function at the original endpoints.
@@ -144,7 +144,7 @@ double GoldenSectionSearch::doStep() throw (Exception)
   {
     // One possible outcome, its housekeeping,
     NumTools::shift<double>(x0, x1, x2);
-    x2 = NumConstants::GOLDEN_RATIO_R * x1 + NumConstants::GOLDEN_RATIO_C * x3;
+    x2 = NumConstants::GOLDEN_RATIO_R() * x1 + NumConstants::GOLDEN_RATIO_C() * x3;
     // and a new function evaluation.
     getParameter_(0).setValue(x2);
     tolIsReached_ = nbEval_ > 2 && getStopCondition()->isToleranceReached();
@@ -155,7 +155,7 @@ double GoldenSectionSearch::doStep() throw (Exception)
   {
     // The other outcome,
     NumTools::shift<double>(x3, x2, x1);
-    x1 = NumConstants::GOLDEN_RATIO_R * x2 + NumConstants::GOLDEN_RATIO_C * x0;
+    x1 = NumConstants::GOLDEN_RATIO_R() * x2 + NumConstants::GOLDEN_RATIO_C() * x0;
     // and its new function evaluation.
     getParameter_(0).setValue(x1);
     tolIsReached_ = nbEval_ > 2 && getStopCondition()->isToleranceReached();
