@@ -47,6 +47,7 @@ knowledge of the CeCILL license and that you accept its terms.
 
 #include <cmath>
 // for abs() below
+#include <climits>
 
 #include "Matrix.h"
 #include "../NumTools.h"
@@ -103,15 +104,16 @@ template <class Real>
 class EigenValue
 {
 
+  private:
    /** 
     * @brief Row and column dimension (square matrix).
     */
-   int n_;
+   size_t n_;
 
    /**
     * @brief Tell if the matrix is symmetric.
     */
-   bool isSymmetric_;
+   bool issymmetric_;
 
    /**
     * @name Arrays for internal storage of eigenvalues.
@@ -149,7 +151,6 @@ class EigenValue
     */
    std::vector<Real> ort_;
 
-
    /**
     * @brief Symmetric Householder reduction to tridiagonal form.
     *
@@ -160,14 +161,14 @@ class EigenValue
     */
    void tred2()
    {
-     for (int j = 0; j < n_; j++)
+     for (size_t j = 0; j < n_; j++)
      {
        d_[j] = V_(n_-1,j);
      }
 
      // Householder reduction to tridiagonal form.
    
-     for (int i = n_-1; i > 0; i--)
+     for (int i = static_cast<int>(n_)-1; i > 0; i--)
      {
        // Scale to avoid under/overflow.
    
@@ -252,36 +253,36 @@ class EigenValue
    
      // Accumulate transformations.
    
-     for (int i = 0; i < n_-1; i++)
+     for (size_t i = 0; i < n_-1; i++)
      {
        V_(n_-1,i) = V_(i,i);
        V_(i,i) = 1.0;
        Real h = d_[i+1];
        if (h != 0.0)
        {
-         for (int k = 0; k <= i; k++)
+         for (size_t k = 0; k <= i; k++)
          {
            d_[k] = V_(k,i+1) / h;
          }
-         for (int j = 0; j <= i; j++)
+         for (size_t j = 0; j <= i; j++)
          {
            Real g = 0.0;
-           for (int k = 0; k <= i; k++)
+           for (size_t k = 0; k <= i; k++)
            {
              g += V_(k,i+1) * V_(k,j);
            }
-           for (int k = 0; k <= i; k++)
+           for (size_t k = 0; k <= i; k++)
            {
              V_(k,j) -= g * d_[k];
            }
          }
        }
-       for (int k = 0; k <= i; k++)
+       for (size_t k = 0; k <= i; k++)
        {
          V_(k,i+1) = 0.0;
        }
      }
-     for (int j = 0; j < n_; j++)
+     for (size_t j = 0; j < n_; j++)
      {
        d_[j] = V_(n_-1,j);
        V_(n_-1,j) = 0.0;
@@ -300,7 +301,7 @@ class EigenValue
     */
    void tql2 ()
    {
-     for (int i = 1; i < n_; i++)
+     for (size_t i = 1; i < n_; i++)
      {
        e_[i-1] = e_[i];
      }
@@ -309,7 +310,7 @@ class EigenValue
      Real f = 0.0;
      Real tst1 = 0.0;
      Real eps = pow(2.0,-52.0);
-     for (int l = 0; l < n_; l++)
+     for (int l = 0; l < static_cast<int>(n_); l++)
      {
        // Find small subdiagonal element
    
@@ -317,7 +318,7 @@ class EigenValue
        int m = l;
 
        // Original while-loop from Java code
-       while (m < n_)
+       while (m < static_cast<int>(n_))
        {
          if (NumTools::abs<Real>(e_[m]) <= eps*tst1)
          {
@@ -349,7 +350,7 @@ class EigenValue
            d_[l+1] = e_[l] * (p + r);
            Real dl1 = d_[l+1];
            Real h = g - d_[l];
-           for (int i = l+2; i < n_; i++)
+           for (size_t i = l+2; i < n_; i++)
            {
              d_[i] -= h;
            }
@@ -380,7 +381,7 @@ class EigenValue
    
              // Accumulate transformation.
    
-             for (int k = 0; k < n_; k++)
+             for (size_t k = 0; k < n_; k++)
              {
                h = V_(k,i+1);
                V_(k,i+1) = s * V_(k,i) + c * h;
@@ -401,11 +402,11 @@ class EigenValue
      
      // Sort eigenvalues and corresponding vectors.
    
-     for (int i = 0; i < n_-1; i++)
+     for (size_t i = 0; n_ > 0 && i < n_-1; i++)
      {
-       int k = i;
+       size_t k = i;
        Real p = d_[i];
-       for (int j = i+1; j < n_; j++)
+       for (size_t j = i+1; j < n_; j++)
        {
          if (d_[j] < p)
          {
@@ -417,7 +418,7 @@ class EigenValue
        {
          d_[k] = d_[i];
          d_[i] = p;
-         for (int j = 0; j < n_; j++)
+         for (size_t j = 0; j < n_; j++)
          {
            p = V_(j,i);
            V_(j,i) = V_(j,k);
@@ -438,7 +439,7 @@ class EigenValue
    void orthes ()
    {
      int low = 0;
-     int high = n_-1;
+     int high = static_cast<int>(n_)-1;
    
      for (int m = low+1; m <= high-1; m++)
      {
@@ -470,7 +471,7 @@ class EigenValue
          // Apply Householder similarity transformation
          // H = (I-u*u'/h)*H*(I-u*u')/h)
    
-         for (int j = m; j < n_; j++)
+         for (int j = m; j < static_cast<int>(n_); j++)
          {
            Real f = 0.0;
            for (int i = high; i >= m; i--)
@@ -504,9 +505,9 @@ class EigenValue
    
      // Accumulate transformations (Algol's ortran).
 
-     for (int i = 0; i < n_; i++)
+     for (size_t i = 0; i < n_; i++)
      {
-       for (int j = 0; j < n_; j++)
+       for (size_t j = 0; j < n_; j++)
        {
          V_(i,j) = (i == j ? 1.0 : 0.0);
        }
@@ -573,7 +574,7 @@ class EigenValue
   
     // Initialize
    
-    int nn = this->n_;
+    int nn = static_cast<int>(this->n_);
     int n = nn-1;
     int low = 0;
     int high = nn-1;
@@ -1094,6 +1095,8 @@ class EigenValue
 
   public:
 
+   bool isSymmetric() const { return issymmetric_; }
+
 
     /**
      * @brief Check for symmetry, then construct the eigenvalue decomposition
@@ -1102,7 +1105,7 @@ class EigenValue
      */
     EigenValue(const Matrix<Real>& A) :
       n_(A.getNumberOfColumns()),
-      isSymmetric_(true),
+      issymmetric_(true),
       d_(n_),
       e_(n_),
       V_(n_,n_),
@@ -1111,19 +1114,21 @@ class EigenValue
       ort_(),
       cdivr(), cdivi()
     {
-      for (int j = 0; (j < n_) && isSymmetric_; j++)
+      if (n_ > INT_MAX)
+        throw Exception("EigenValue: can only be computed for matrices <= " + TextTools::toString(INT_MAX));
+      for (size_t j = 0; (j < n_) && issymmetric_; j++)
       {
-        for (int i = 0; (i < n_) && isSymmetric_; i++)
+        for (size_t i = 0; (i < n_) && issymmetric_; i++)
         {
-          isSymmetric_ = (A(i,j) == A(j,i));
+          issymmetric_ = (A(i,j) == A(j,i));
         }
       }
 
-      if (isSymmetric_)
+      if (issymmetric_)
       {
-        for (int i = 0; i < n_; i++)
+        for (size_t i = 0; i < n_; i++)
         {
-          for (int j = 0; j < n_; j++)
+          for (size_t j = 0; j < n_; j++)
           {
             V_(i,j) = A(i,j);
           }
@@ -1140,9 +1145,9 @@ class EigenValue
         H_.resize(n_,n_);
         ort_.resize(n_);
          
-        for (int j = 0; j < n_; j++)
+        for (size_t j = 0; j < n_; j++)
         {
-          for (int i = 0; i < n_; i++)
+          for (size_t i = 0; i < n_; i++)
           {
             H_(i,j) = A(i,j);
           }
@@ -1213,9 +1218,9 @@ class EigenValue
      */
     const RowMatrix<Real>& getD() const
     {
-      for (int i = 0; i < n_; i++)
+      for (size_t i = 0; i < n_; i++)
       {
-        for (int j = 0; j < n_; j++)
+        for (size_t j = 0; j < n_; j++)
         {
           D_(i,j) = 0.0;
         }
@@ -1231,13 +1236,6 @@ class EigenValue
       }
       return D_;
     }
-
-    /**
-     * @brief Tells is the input matrix is symmetric.
-     *
-     * @return true is the input matrix is symmetric.
-     */
-    bool isSymmetric() const { return isSymmetric_; }
 };
 
 } //end of namespace bpp.
