@@ -1,11 +1,11 @@
 //
-// File: Constants.h
+// File: NumConstants.h
 // Created by: Julien Dutheil
 // Created on: Tue Feb 03 14:21 2009
 //
 
 /*
-  Copyright or © or Copr. CNRS, (November 17, 2004)
+  Copyright or © or Copr. Bio++ Development Team, (November 17, 2004)
 
   This software is a computer program whose purpose is to provide classes
   for numerical calculus. This file is part of the Bio++ project.
@@ -40,13 +40,20 @@
 #ifndef _NUMCONSTANTS_H_
 #define _NUMCONSTANTS_H_
 
+#include <cmath>
+#include <limits>
+
 namespace bpp {
 
   /**
    * @brief this static class contains several useful constant values.
+   *
+   * This classe uses function in order to avoid the infamous "static initialization order fiasco".
+   * C++0x solves this...
    */
   class NumConstants
   {
+
   public:
     /**
      * @name Golden ratio.
@@ -55,26 +62,38 @@ namespace bpp {
      * We also define @f$R=\phi-1@f$ and @f$C = 1 - R@f$.
      * @{
      */
-    static const double GOLDEN_RATIO_PHI;
-    static const double GOLDEN_RATIO_R;
-    static const double GOLDEN_RATIO_C;
+    static double GOLDEN_RATIO_PHI() { return (1. + sqrt(5.)) / 2.; }
+    static double GOLDEN_RATIO_R() { return GOLDEN_RATIO_PHI() - 1.; }
+    static double GOLDEN_RATIO_C() { return 1. - GOLDEN_RATIO_R(); }
+
     /** @} */
 
-    static const double MEGA;
-    static const double KILO;
-    static const double DECI;
-    static const double CENTI;
-    static const double MILLI;
-    static const double MICRO;
-    static const double NANO;
-    static const double PICO;
-    
-    static const double SMALL;
-    static const double TINY;
-    static const double VERY_TINY;
-    static const double VERY_BIG;
+    static double MEGA() { return 1e6; }
+    static double KILO() { return 1e3; }
+    static double DECI() { return 1e-1; }
+    static double CENTI() { return 1e-2; }
+    static double MILLI() { return 1e-3; }
+    static double MICRO() { return 1e-6; }
+    static double NANO() { return 1e-9; }
+    static double PICO() { return 1e-12; }
 
-    static const double PI;
+    static double SMALL() { return 1e-6; }
+    static double TINY() { return 1e-12; }
+    static double VERY_TINY() { return 1e-20; }
+    static double VERY_BIG() { return static_cast<double>(1.7E+23); }
+    
+    /**
+     * @name Define those constants in case they would not be available in stl/limits.
+     *
+     * @{
+     */
+    static double INF() { return std::numeric_limits<double>::has_infinity ? -log(0) : std::numeric_limits<double>::max(); }
+    static double PINF() { return std::numeric_limits<double>::has_infinity ? -log(0) : std::numeric_limits<double>::max(); }
+    static double MINF() { return std::numeric_limits<double>::has_infinity ? log(0) : std::numeric_limits<double>::min(); }
+    static double NaN() { return 3./0.; }
+    /** @} */
+
+    static double PI() { return 3.141593; }
   };
 
 }//end of namespace bpp.
