@@ -138,28 +138,47 @@ namespace bpp
   protected:
     std::string name_;             //Parameter name
     double value_;            //Parameter value
+    double precision_;  // Precision needed for Parameter value
     Constraint* constraint_; //A constraint on the value
     bool attach_;   // Tells if the constraint is attached to the Parameter
     std::vector<ParameterListener*> listeners_;
     std::vector<bool> listenerAttach_;
   
   public: // Class constructors and destructors:
-    
+
+    /**
+     * @brief Default contructor. Creates a parameter with no name, no constraint, and a value of 0.
+     */
+    Parameter(): name_(""), value_(0), precision_(0), constraint_(0), attach_(true), listeners_(), listenerAttach_() {}
     /**
      * @brief Build a new parameter.
      *
      * @param name       The parameter name.
      * @param value      The parameter value.
-     * @param constraint An optional pointer toward a constraint Object.
+     * @param constraint A  pointer toward a constraint Object.
      * @param attachConstraint Tell if the constraint must be attached to this parameter, or shared
+     * @param precision An optional parameter precision (default 0)
      * between different objects (the default behavior, for backward compatibility).
      * If the first case, the constraint object will be destroyed when the parameter is destroyed,
-     * and duplicated whe the parameter is copied.
+     * and duplicated when the parameter is copied.
      * @throw ConstraintException If the parameter value does not match the contraint.
      */
-    Parameter(const std::string& name = "", double value = 0, Constraint* constraint = 0, bool attachConstraint = false)
+    Parameter(const std::string& name, double value, Constraint* constraint, bool attachConstraint, double precision=0)
       throw (ConstraintException);
 
+    /**
+     * @brief Build a new parameter.
+     *
+     * @param name       The parameter name.
+     * @param value      The parameter value.
+     * @param constraint An optional pointer toward a constraint Object. The constraint will be copied and attached to this instance.
+     * @param precision An optional parameter precision (default 0)
+     * @throw ConstraintException If the parameter value does not match the contraint.
+     */
+    Parameter(const std::string& name, double value, const Constraint* constraint = 0, double precision=0)
+      throw (ConstraintException);
+
+
     /**
      * @brief Copy constructor.
      */
@@ -200,6 +219,13 @@ namespace bpp
      */
     virtual void setValue(double value) throw (ConstraintException);
   
+    /**
+     * @brief Set the precision of this parameter.
+     *
+     * @param precision the new parameter precision.
+     */
+    void setPrecision(double precision);
+    
     /**
      * @brief Get the name of this parameter.
      *
@@ -214,6 +240,13 @@ namespace bpp
      */
     virtual double getValue() const { return value_; }
     
+    /**
+     * @brief Get the precision of this parameter.
+     *
+     * @return The precision value.
+     */
+    virtual double getPrecision() const { return precision_; }
+    
     /**
      * @brief Return the constraint associated to this parameter if there is one.
      *
@@ -297,12 +330,12 @@ namespace bpp
     }
   
   public:
-    static IncludingPositiveReal R_PLUS;
-    static ExcludingPositiveReal R_PLUS_STAR;
-    static IncludingNegativeReal R_MINUS;
-    static ExcludingNegativeReal R_MINUS_STAR;
-    static IncludingInterval PROP_CONSTRAINT_IN;
-    static ExcludingInterval PROP_CONSTRAINT_EX;
+    static const IntervalConstraint R_PLUS;
+    static const IntervalConstraint R_PLUS_STAR;
+    static const IntervalConstraint R_MINUS;
+    static const IntervalConstraint R_MINUS_STAR;
+    static const IntervalConstraint PROP_CONSTRAINT_IN;
+    static const IntervalConstraint PROP_CONSTRAINT_EX;
   };
 
 } //end of namespace bpp.
