@@ -139,7 +139,7 @@ ParameterList ParameterList::subList(const std::string& name) const throw (Param
 }
 
 /******************************************************************************/
-ParameterList ParameterList::subList(const std::vector<unsigned int>& parameters) const
+ParameterList ParameterList::subList(const std::vector<size_t>& parameters) const
 {
   ParameterList pl;
   for (unsigned int i = 0; i < parameters.size(); i++)
@@ -150,7 +150,7 @@ ParameterList ParameterList::subList(const std::vector<unsigned int>& parameters
 }
 
 /******************************************************************************/
-ParameterList ParameterList::subList(unsigned int parameter) const
+ParameterList ParameterList::subList(size_t parameter) const
 {
   ParameterList pl;
   if (parameter < size()) pl.parameters_.push_back(dynamic_cast<Parameter*>(parameters_[parameter]->clone()));
@@ -165,7 +165,8 @@ ParameterList ParameterList::getCommonParametersWith(const ParameterList& params
   {
     const Parameter& p = params[i];
     if (hasParameter(p.getName()))
-      pl.parameters_.push_back(dynamic_cast<Parameter*>(p.clone()));                                                                        // We use push_back instead of addParameter because we are sure the name is not duplicated.
+      pl.parameters_.push_back(dynamic_cast<Parameter*>(p.clone()));                                                                        
+    // We use push_back instead of addParameter because we are sure the name is not duplicated.
   }
 
   return pl;
@@ -184,6 +185,7 @@ std::vector<std::string> ParameterList::getParameterNames() const
 }
 
 /******************************************************************************/
+
 void ParameterList::addParameter(const Parameter& param) throw (ParameterException)
 {
   if (hasParameter(param.getName()))
@@ -192,7 +194,17 @@ void ParameterList::addParameter(const Parameter& param) throw (ParameterExcepti
 }
 
 /******************************************************************************/
-void ParameterList::setParameter(unsigned int index, const Parameter& param) throw (IndexOutOfBoundsException)
+
+void ParameterList::addParameter(Parameter* param) throw (ParameterException)
+{
+  if (hasParameter(param->getName()))
+    throw ParameterException("ParameterList::addParameter. Parameter with name '" + param->getName() + "' already exists.", param);
+  parameters_.push_back(param);
+}
+
+/******************************************************************************/
+
+void ParameterList::setParameter(size_t index, const Parameter& param) throw (IndexOutOfBoundsException)
 {
   if (index >= size()) throw IndexOutOfBoundsException("ParameterList::setParameter.", index, 0, size());
   delete parameters_[index];
@@ -200,6 +212,7 @@ void ParameterList::setParameter(unsigned int index, const Parameter& param) thr
 }
 
 /******************************************************************************/
+
 void ParameterList::includeParameters(const ParameterList& params)
 {
   for (unsigned int i = 0; i < params.size(); i++)
@@ -212,6 +225,7 @@ void ParameterList::includeParameters(const ParameterList& params)
 }
 
 /******************************************************************************/
+
 void ParameterList::addParameters(const ParameterList& params)
 throw (ParameterException)
 {
@@ -222,6 +236,7 @@ throw (ParameterException)
 }
 
 /******************************************************************************/
+
 void ParameterList::setParameterValue(const string& name, double value)
 throw (ParameterNotFoundException, ConstraintException)
 {
@@ -230,6 +245,7 @@ throw (ParameterNotFoundException, ConstraintException)
 }
 
 /******************************************************************************/
+
 void ParameterList::setAllParametersValues(const ParameterList& params)
 throw (ParameterNotFoundException, ConstraintException)
 {
@@ -250,6 +266,7 @@ throw (ParameterNotFoundException, ConstraintException)
 }
 
 /******************************************************************************/
+
 void ParameterList::setParametersValues(const ParameterList& params)
 {
   // First we check if all values are correct:
@@ -277,6 +294,7 @@ void ParameterList::setParametersValues(const ParameterList& params)
 }
 
 /******************************************************************************/
+
 bool ParameterList::testParametersValues(const ParameterList& params) const
 {
   // First we check if all values are correct:
@@ -306,6 +324,7 @@ bool ParameterList::testParametersValues(const ParameterList& params) const
 }
 
 /******************************************************************************/
+
 bool ParameterList::matchParametersValues(const ParameterList& params)
 throw (ConstraintException)
 {
@@ -409,7 +428,7 @@ void ParameterList::deleteParameters(const std::vector<std::string>& names) thro
 }
 
 /******************************************************************************/
-void ParameterList::deleteParameter(unsigned int index) throw (IndexOutOfBoundsException)
+void ParameterList::deleteParameter(size_t index) throw (IndexOutOfBoundsException)
 {
   if (index >= size()) throw IndexOutOfBoundsException("ParameterList::deleteParameter.", index, 0, size());
   Parameter* p = parameters_[index];
@@ -418,13 +437,13 @@ void ParameterList::deleteParameter(unsigned int index) throw (IndexOutOfBoundsE
 }
 
 /******************************************************************************/
-void ParameterList::deleteParameters(const std::vector<unsigned int>& indices) throw (IndexOutOfBoundsException)
+void ParameterList::deleteParameters(const std::vector<size_t>& indices) throw (IndexOutOfBoundsException)
 {
-  vector<unsigned int> tmp(indices);
+  vector<size_t> tmp(indices);
   sort(tmp.begin(), tmp.end());
-  for (vector<unsigned int>::reverse_iterator i = tmp.rbegin(); i != tmp.rend(); i++)
+  for (vector<size_t>::reverse_iterator i = tmp.rbegin(); i != tmp.rend(); i++)
   {
-    unsigned int index = *i;
+    size_t index = *i;
     if (index >= size()) throw IndexOutOfBoundsException("ParameterList::deleteParameter.", index, 0, size());
     Parameter* p = parameters_[index];
     delete p;
@@ -433,9 +452,9 @@ void ParameterList::deleteParameters(const std::vector<unsigned int>& indices) t
 }
 
 /******************************************************************************/
-unsigned int ParameterList::whichParameterHasName(const std::string& name) const throw (ParameterNotFoundException)
+size_t ParameterList::whichParameterHasName(const std::string& name) const throw (ParameterNotFoundException)
 {
-  for (unsigned int i = 0; i < size(); i++)
+  for (size_t i = 0; i < size(); i++)
   {
     if (parameters_[i]->getName() == name) return i;
   }
