@@ -46,21 +46,21 @@ using namespace bpp;
 using namespace std;
 
 
-AbstractDiscreteDistribution::AbstractDiscreteDistribution(unsigned int nbClasses, const std::string& prefix) :
+AbstractDiscreteDistribution::AbstractDiscreteDistribution(size_t nbClasses, const std::string& prefix) :
   AbstractParameterAliasable(prefix),
   numberOfCategories_(nbClasses),
   distribution_(),
-  bounds_(),
-  intMinMax_(-NumConstants::VERY_BIG, NumConstants::VERY_BIG, true, true),
+  bounds_(nbClasses-1),
+  intMinMax_(-NumConstants::VERY_BIG(), NumConstants::VERY_BIG(), true, true),
   median_(false)
 {}
 
-AbstractDiscreteDistribution::AbstractDiscreteDistribution(unsigned int nbClasses, double delta, const std::string& prefix) :
+AbstractDiscreteDistribution::AbstractDiscreteDistribution(size_t nbClasses, double delta, const std::string& prefix) :
   AbstractParameterAliasable(prefix),
   numberOfCategories_(nbClasses),
   distribution_(Order(delta)),
-  bounds_(),
-  intMinMax_(-NumConstants::VERY_BIG, NumConstants::VERY_BIG,true, true),
+  bounds_(nbClasses-1),
+  intMinMax_(-NumConstants::VERY_BIG(), NumConstants::VERY_BIG(),true, true),
   median_(false)
 {}
 
@@ -88,12 +88,12 @@ AbstractDiscreteDistribution& AbstractDiscreteDistribution::operator=(const Abst
 
 /******************************************************************************/
 
-unsigned int AbstractDiscreteDistribution::getNumberOfCategories() const
+size_t AbstractDiscreteDistribution::getNumberOfCategories() const
 {
   return numberOfCategories_;
 }
 
-void AbstractDiscreteDistribution::setNumberOfCategories(unsigned int nbClasses)
+void AbstractDiscreteDistribution::setNumberOfCategories(size_t nbClasses)
 {
   if (nbClasses <= 0)
     cerr << "DEBUG: ERROR!!! Number of categories is <= 0 in AbstractDiscreteDistribution::setNumberOfCategories()." << endl;
@@ -108,7 +108,7 @@ void AbstractDiscreteDistribution::setNumberOfCategories(unsigned int nbClasses)
 
 /******************************************************************************/
 
-double AbstractDiscreteDistribution::getCategory(unsigned int categoryIndex) const
+double AbstractDiscreteDistribution::getCategory(size_t categoryIndex) const
 {
   map<double, double>::const_iterator it = distribution_.begin();
   for (unsigned int i = 0; i < categoryIndex; i++)
@@ -120,7 +120,7 @@ double AbstractDiscreteDistribution::getCategory(unsigned int categoryIndex) con
 
 /******************************************************************************/
 
-double AbstractDiscreteDistribution::getProbability(unsigned int categoryIndex) const
+double AbstractDiscreteDistribution::getProbability(size_t categoryIndex) const
 {
   map<double, double>::const_iterator it = distribution_.begin();
   for (unsigned int i = 0; i < categoryIndex; i++)
@@ -286,22 +286,23 @@ void AbstractDiscreteDistribution::print(OutputStream& out) const
 
 /******************************************************************************/
 
-double AbstractDiscreteDistribution::getValueCategory(double value) const throw (OutOfRangeException)
+double AbstractDiscreteDistribution::getValueCategory(double value) const
 {
-  return getDomain().getNearestValue(value);
+  if (!(intMinMax_.isCorrect(value)))
+    throw Exception("AbstractDiscreteDistribution::getValueCategory out of bounds:" + TextTools::toString(value));
+
+  map<double, double>::const_iterator it = distribution_.begin();
+  for (unsigned int i=1;i<bounds_.size();i++)
+    if (value<bounds_[i])
+      break;
+    else
+      it++;
+
+  return it->first;
 }
 
 /***********************************************************************/
 
-double AbstractDiscreteDistribution::getLowerBound() const
-{
-  return bounds_[0];
-}
-
-double AbstractDiscreteDistribution::getUpperBound() const
-{
-  return bounds_[getNumberOfCategories()];
-}
 
 void AbstractDiscreteDistribution::discretize()
 {
@@ -310,75 +311,79 @@ void AbstractDiscreteDistribution::discretize()
    */
 
   distribution_.clear();
-  bounds_.resize(numberOfCategories_ + 1);
-  bounds_[0] = intMinMax_.getLowerBound() + (intMinMax_.strictLowerBound() ? precision() : 0);
-  bounds_[numberOfCategories_] = intMinMax_.getUpperBound() - (intMinMax_.strictUpperBound() ? precision() : 0);
+  bounds_.resize(numberOfCategories_ - 1);
 
-  double minX = pProb(bounds_[0]);
-  double maxX = pProb(bounds_[numberOfCategories_]);
+  double minX = pProb(intMinMax_.getLowerBound());
+  double maxX = pProb(intMinMax_.getUpperBound());
 
   double ec;
-  unsigned int i;
+  size_t i;
   vector<double> values(numberOfCategories_);
 
-  // if maxX==minX, uniform discretization of the range
   if (maxX != minX)
   {
-    ec = (maxX - minX) / numberOfCategories_;
+    // divide the domain into equiprobable intervals
+    ec = (maxX - minX) / static_cast<double>(numberOfCategories_);
 
     for (i = 1; i < numberOfCategories_; i++)
     {
-      bounds_[i] = qProb(minX + i * ec);
+      bounds_[i-1] = qProb(minX + static_cast<double>(i) * ec);
     }
 
+    // for each category, sets the value v as the median, adjusted
+    //      such that the sum of the values = 1
     if (median_)
     {
-      double t;
+      double t=0;
       for (i = 0; i < numberOfCategories_; i++)
-        values[i] = qProb(minX + (i + 0.5) * ec);
+        values[i] = qProb(minX + (static_cast<double>(i) + 0.5) * ec);
 
       for (i = 0, t = 0; i < numberOfCategories_; i++)
         t += values[i];
-      double mean = Expectation(bounds_[numberOfCategories_]) - Expectation(bounds_[0]);
+
+      double mean = Expectation(intMinMax_.getUpperBound()) - Expectation(intMinMax_.getLowerBound());
+
       for (i = 0; i < numberOfCategories_; i++)
-        values[i] *= mean / t * numberOfCategories_ / (maxX - minX);
+        values[i] *= mean / t / ec;
     }
     else
-    {
-      if (numberOfCategories_ == 1)
-        values[0] = Expectation(bounds_[1]) - Expectation(bounds_[0]);
-      else
+      // for each category, sets the value v such that
+      //      v * length_of_the_interval = the surface of the category
       {
-        double a = Expectation(bounds_[0]), b;
-        for (i = 0; i < numberOfCategories_; i++)
+      double a = Expectation(intMinMax_.getLowerBound()), b;
+      for (i = 0; i < numberOfCategories_-1; i++)
         {
-          b = Expectation(bounds_[i + 1]);
-          values[i] = (b - a) * numberOfCategories_ / (maxX - minX);
+          b = Expectation(bounds_[i]);
+          values[i] = (b - a) / ec;
           a = b;
         }
-      }
+      values[numberOfCategories_-1] = (Expectation(intMinMax_.getUpperBound())-a) / ec;
     }
   }
-  else
+  else 
+    // if maxX==minX, uniform discretization of the range
   {
-    ec = (bounds_[numberOfCategories_] - bounds_[0]) / numberOfCategories_;
+    ec = (intMinMax_.getUpperBound() - intMinMax_.getLowerBound()) / static_cast<double>(numberOfCategories_);
     for (i = 1; i < numberOfCategories_; i++)
-    {
-      bounds_[i] = bounds_[0] + i * ec;
-    }
+      bounds_[i-1] = intMinMax_.getLowerBound() + static_cast<double>(i) * ec;
 
-    for (i = 0; i < numberOfCategories_; i++)
-    {
-      values[i] = (bounds_[i] + bounds_[i + 1]) / 2;
-    }
+    values[0] = (intMinMax_.getLowerBound() + bounds_[0]) / 2;
+    
+    for (i = 1; i < numberOfCategories_-1; i++)
+      values[i] = (bounds_[i-1] + bounds_[i]) / 2;
+
+    values[numberOfCategories_-1] = (intMinMax_.getUpperBound()+bounds_[numberOfCategories_ - 1]) / 2;
   }
 
+  // adjustments near the boundaries of the domain, according to the precision chosen
   if (intMinMax_.strictLowerBound())
   {
     for (i = 0; i < numberOfCategories_; i++)
     {
       if (values[i] < intMinMax_.getLowerBound() + precision())
         values[i] = intMinMax_.getLowerBound() + precision();
+      else
+        break;
     }
   }
   else
@@ -387,32 +392,41 @@ void AbstractDiscreteDistribution::discretize()
     {
       if (values[i] < intMinMax_.getLowerBound())
         values[i] = intMinMax_.getLowerBound() + precision();
+      else
+        break;
     }
   }
 
   if (intMinMax_.strictUpperBound())
   {
-    for (i = 0; i < numberOfCategories_; i++)
+    for (i = numberOfCategories_; i > 0; i--)
     {
-      if (values[i] > intMinMax_.getUpperBound() - precision())
-        values[i] = intMinMax_.getUpperBound() - precision();
+      if (values[i-1] > intMinMax_.getUpperBound() - precision())
+        values[i-1] = intMinMax_.getUpperBound() - precision();
+      else
+        break;
     }
   }
   else
   {
-    for (i = 0; i < numberOfCategories_; i++)
+    for (i = numberOfCategories_; i > 0; i--)
     {
-      if (values[i] > intMinMax_.getUpperBound())
-        values[i] = intMinMax_.getUpperBound() - precision();
+      if (values[i-1] > intMinMax_.getUpperBound())
+        values[i-1] = intMinMax_.getUpperBound() - precision();
+      else
+        break;
     }
   }
+
+  // now the distribution_ map, taking care that all values are different
+  
   double p = 1. / static_cast<double>(numberOfCategories_);
   for (i = 0; i < numberOfCategories_; i++)
   {
     if (distribution_.find(values[i]) != distribution_.end())
     {
       unsigned int j = 1;
-      int f = ((values[i] + NumConstants::TINY) >= intMinMax_.getUpperBound()) ? -1 : 1;
+      int f = ((values[i] + NumConstants::TINY()) >= intMinMax_.getUpperBound()) ? -1 : 1;
       while (distribution_.find(values[i] + f * j * precision()) != distribution_.end())
       {
         j++;
@@ -427,10 +441,19 @@ void AbstractDiscreteDistribution::discretize()
   return;
 }
 
+Vdouble AbstractDiscreteDistribution::getBounds() const
+{
+  Vdouble vb(numberOfCategories_ + 1);
+  vb[0] = getLowerBound();
+  for (unsigned int i = 0; i < numberOfCategories_ - 1; i++)
+    vb[i + 1] = getBound(i);
+  vb[numberOfCategories_] = getUpperBound();
+  return vb;
+}
 
 void AbstractDiscreteDistribution::restrictToConstraint(const Constraint& c)
 {
-  const Interval* pi = dynamic_cast<const Interval*>(&c);
+  const IntervalConstraint* pi = dynamic_cast<const IntervalConstraint*>(&c);
 
   if (!pi)
     throw Exception("AbstractDiscreteDistribution::restrictToConstraint: the constraint is not an interval");
