@@ -73,7 +73,7 @@ namespace bpp
       
     public:
 
-      Order(double prec=NumConstants::TINY):
+      Order(double prec=NumConstants::TINY()):
         precision_(prec)
       {}
 
@@ -108,8 +108,7 @@ namespace bpp
      * The number of categories
      */
 
-    unsigned int numberOfCategories_;
-    
+    size_t numberOfCategories_;  
     /**
      * These fields must be initialized in the constructor of the derived classes.
      */
@@ -122,7 +121,7 @@ namespace bpp
      *
      */
     
-    Interval intMinMax_;    
+    IntervalConstraint intMinMax_;    
 
     /**
      * Tells if the values in the classes is associated to the median or not (default: false)
@@ -132,14 +131,13 @@ namespace bpp
     bool median_;
     
   public:
-    AbstractDiscreteDistribution(unsigned int nbClasses, const std::string& prefix = ""); 
+    AbstractDiscreteDistribution(size_t nbClasses, const std::string& prefix = ""); 
 
-    /*
-    * With additional precision value to discriminate categories (default 1e-12)
-    *
-    */
-    
-    AbstractDiscreteDistribution(unsigned int nbClasses, double precision, const std::string& prefix = "");
+    /**
+     * With additional precision value to discriminate categories (default 1e-12)
+     *
+     */
+    AbstractDiscreteDistribution(size_t nbClasses, double precision, const std::string& prefix = "");
     
     AbstractDiscreteDistribution(const AbstractDiscreteDistribution& adde);
 
@@ -155,14 +153,14 @@ namespace bpp
      *
      * @{
      */
-    unsigned int getNumberOfCategories() const;
-    void setNumberOfCategories(unsigned int nbClasses);
-    double getCategory(unsigned int categoryIndex) const;
-    double getProbability(unsigned int categoryIndex) const;
+    size_t getNumberOfCategories() const;
+    void setNumberOfCategories(size_t nbClasses);
+    double getCategory(size_t categoryIndex) const;
+    double getProbability(size_t categoryIndex) const;
     double getProbability(double category) const;
     Vdouble getCategories() const;
     Vdouble getProbabilities() const;
-    double getValueCategory(double value) const throw (OutOfRangeException);
+    double getValueCategory(double value) const;
     void set(double category, double probability);
     void add(double category, double probability);
     double getInfCumulativeProbability(double category) const;
@@ -171,9 +169,48 @@ namespace bpp
     double getSSupCumulativeProbability(double category) const;
     double rand() const;
     double randC() const throw (Exception) { throw Exception("AbstractDiscreteDistribution::randC. No continuous version available for this distribution."); }
-    virtual double getLowerBound() const;
-    virtual double getUpperBound() const;
 
+    /*
+     *@return value of the internal bound
+     *
+     */
+    
+    double getBound(size_t i) const throw (IndexOutOfBoundsException)
+    {
+      if (i >= numberOfCategories_ - 1)
+        throw IndexOutOfBoundsException("AbstractDiscreteDistribution::getBound(i)", i , 0, numberOfCategories_-1);
+      return bounds_[i];
+    }  
+
+
+    /*
+     *@brief Information about the range of the distribution
+     *
+     */
+     
+
+    double getLowerBound() const
+    {
+      return intMinMax_.getLowerBound();
+    }
+
+    double getUpperBound() const
+    {
+      return intMinMax_.getUpperBound();
+    }
+
+    bool strictLowerBound() const
+    {
+      return intMinMax_.strictLowerBound();
+    }
+
+    bool strictUpperBound() const
+    {
+      return intMinMax_.strictUpperBound();
+    }
+
+    Vdouble getBounds() const;
+    
     void print(OutputStream& out) const;
 
     double precision() const { return distribution_.key_comp().precision();}
