@@ -51,18 +51,18 @@ using namespace std;
 
 /** Constructor: **************************************************************/
 
-BetaDiscreteDistribution::BetaDiscreteDistribution(unsigned int n, double alpha, double beta) :
+BetaDiscreteDistribution::BetaDiscreteDistribution(size_t n, double alpha, double beta) :
   AbstractParameterAliasable("Beta."),
-  AbstractDiscreteDistribution(n,NumConstants::VERY_TINY,"Beta."), alpha_(alpha), beta_(beta), diffln_(0)
+  AbstractDiscreteDistribution(n,NumConstants::VERY_TINY(),"Beta."), alpha_(alpha), beta_(beta), diffln_(0)
 {
-  Parameter p1("Beta.alpha", alpha, new IncludingPositiveReal(0.0001), true);
-  addParameter_(p1);
-  Parameter p2("Beta.beta", beta, new IncludingPositiveReal(0.0001), true);
-  addParameter_(p2);
-  intMinMax_.setLowerBound(0,true);
-  intMinMax_.setUpperBound(1,true);
+  addParameter_(new Parameter("Beta.alpha", alpha, new IntervalConstraint(1, 0.0001, true), true));
 
-  diffln_=exp(RandomTools::lnBeta(alpha_+1,beta_)-RandomTools::lnBeta(alpha_,beta_));
+  // For precision issues, beta cannot be too low
+  addParameter_(new Parameter("Beta.beta", beta, new IntervalConstraint(1, 0.1, true), true));
+  intMinMax_.setLowerBound(0, true);
+  intMinMax_.setUpperBound(1, true);
+
+  diffln_ = exp(RandomTools::lnBeta(alpha_ + 1, beta_) - RandomTools::lnBeta(alpha_, beta_));
   discretize();
 }
 
@@ -104,13 +104,6 @@ void BetaDiscreteDistribution::fireParameterChanged(const ParameterList& paramet
 
 /******************************************************************************/
 
-Domain BetaDiscreteDistribution::getDomain() const
-{
-  return Domain(bounds_, MapTools::getKeys<double, double, AbstractDiscreteDistribution::Order>(distribution_));
-}
-
-/******************************************************************************/
-
 double BetaDiscreteDistribution::qProb(double x) const
 {
   return RandomTools::qBeta(x, alpha_, beta_);
