@@ -40,18 +40,19 @@ knowledge of the CeCILL license and that you accept its terms.
 #include "ConstantDistribution.h"
 
 using namespace bpp;
+
 #include <iostream>
+
 using namespace std;
 
 /******************************************************************************/
 
-ConstantDistribution::ConstantDistribution(double value, bool fixed):
+ConstantDistribution::ConstantDistribution(double value):
   AbstractParameterAliasable("Constant."),
   AbstractDiscreteDistribution(1, "Constant."),
   value_(value)
 {
-  if (! fixed)
-    addParameter_(Parameter("Constant.value", value));
+  addParameter_(new Parameter("Constant.value", value)); 
   distribution_[value_] = 1; //One single class  with probability 1.
 }
 
@@ -59,8 +60,7 @@ ConstantDistribution::ConstantDistribution(const ConstantDistribution& cd) :
   AbstractParameterAliasable(cd),
   AbstractDiscreteDistribution(cd),
   value_(cd.value_)
-{
-}
+{}
 
 ConstantDistribution& ConstantDistribution::operator=(const ConstantDistribution& cd)
 {
@@ -86,26 +86,12 @@ void ConstantDistribution::fireParameterChanged(const ParameterList& parameters)
 
 /******************************************************************************/
 
-Domain ConstantDistribution::getDomain() const
-{
-  return Domain(value_, value_, 1);
-}
-
-/******************************************************************************/
-
-std::string ConstantDistribution::getName() const
-{
-  return("ConstantDistribution");
-}
-
-/******************************************************************************/
-
 void ConstantDistribution::restrictToConstraint(const Constraint& c)
 {
   if (getNumberOfParameters()==0)
     return;
   
-  const Interval* pi=dynamic_cast<const Interval*>(&c);
+  const IntervalConstraint* pi=dynamic_cast<const IntervalConstraint*>(&c);
   if (!pi)
     throw Exception("ConstantDistribution::restrictToConstraint: Non-interval exception");
 
