@@ -50,25 +50,17 @@ using namespace std;
 
 /****************************************************************/
 
-ExponentialDiscreteDistribution::ExponentialDiscreteDistribution(unsigned int n, double lambda, string prefix) :
-  AbstractParameterAliasable(prefix),
-  AbstractDiscreteDistribution(n, prefix),
-  lambdaConstraint_(0),
+ExponentialDiscreteDistribution::ExponentialDiscreteDistribution(size_t n, double lambda) :
+  AbstractParameterAliasable("Exponential."),
+  AbstractDiscreteDistribution(n, "Exponential."),
   lambda_(lambda)
 {
-  lambdaConstraint_ = new IncludingPositiveReal(0.0);
-  Parameter p(prefix + "lambda", lambda, dynamic_cast<Constraint*>(lambdaConstraint_->clone()), true);
-  addParameter_(p);
+  addParameter_(new Parameter("Exponential.lambda", lambda,  &Parameter::R_PLUS));
 
   intMinMax_.setLowerBound(0, true);
   discretize();
 }
 
-ExponentialDiscreteDistribution::~ExponentialDiscreteDistribution()
-{
-  delete lambdaConstraint_;
-}
-
 /******************************************************************************/
 
 void ExponentialDiscreteDistribution::fireParameterChanged(const ParameterList& parameters)
@@ -78,11 +70,5 @@ void ExponentialDiscreteDistribution::fireParameterChanged(const ParameterList&
   discretize();
 }
 
-/******************************************************************************/
-
-Domain ExponentialDiscreteDistribution::getDomain() const
-{
-  return Domain(bounds_, MapTools::getKeys<double, double, AbstractDiscreteDistribution::Order>(distribution_));
-}
 
 
