@@ -55,8 +55,6 @@ class ExponentialDiscreteDistribution :
   public AbstractDiscreteDistribution
 {
 protected:
-  IncludingPositiveReal* lambdaConstraint_;
-
   double lambda_;
 
 public:
@@ -64,18 +62,16 @@ public:
    * @brief Build a new discretized exponential distribution.
    * @param n the number of categories to use.
    * @param lambda The lambda parameter.
-   * @param prefix the spacename (for TruncExponential)
    *
    * The Parameter is: lambda @f$ \in [0;\infty[ @f$.
    *
    */
 
-  ExponentialDiscreteDistribution(unsigned int n, double lambda = 1., std::string prefix = "Exponential.");
+  ExponentialDiscreteDistribution(size_t n, double lambda = 1.);
 
   ExponentialDiscreteDistribution(const ExponentialDiscreteDistribution& dist) :
     AbstractParameterAliasable(dist),
     AbstractDiscreteDistribution(dist),
-    lambdaConstraint_(dynamic_cast<IncludingPositiveReal*>(dist.lambdaConstraint_->clone())),
     lambda_(dist.lambda_)
   {}
 
@@ -83,20 +79,19 @@ public:
   {
     AbstractParameterAliasable::operator=(dist);    
     AbstractDiscreteDistribution::operator=(dist);
-    lambdaConstraint_ = dynamic_cast<IncludingPositiveReal*>(dist.lambdaConstraint_->clone());
     lambda_ = dist.lambda_;
     return *this;
   }
 
-  virtual ~ExponentialDiscreteDistribution();
+  ~ExponentialDiscreteDistribution(){};
 
   ExponentialDiscreteDistribution* clone() const { return new ExponentialDiscreteDistribution(*this); }
 
 public:
-  Domain getDomain() const;
+  std::string getName() const {return("Exponential");}
+  
   void fireParameterChanged(const ParameterList& parameters);
 
-public:
   double randC() const throw (Exception)
   {
     double x = RandomTools::randExponential(1. / getParameterValue("lambda"));
