@@ -51,7 +51,7 @@ using namespace std;
 
 /** Constructor: **************************************************************/
 
-GammaDiscreteDistribution::GammaDiscreteDistribution(unsigned int n, double alpha, double beta, double minimumAlpha, double minimumBeta) :
+GammaDiscreteDistribution::GammaDiscreteDistribution(size_t n, double alpha, double beta, double minimumAlpha, double minimumBeta) :
   AbstractParameterAliasable("Gamma."),
   AbstractDiscreteDistribution(n, "Gamma."),
   alpha_(alpha),
@@ -63,10 +63,8 @@ GammaDiscreteDistribution::GammaDiscreteDistribution(unsigned int n, double alph
   // may have the same category value, leading to a classe number lower than expected.
   // NB: if this is the case, then a warning is shown. This may happen in optimization
   // algorithms.
-  Parameter p1("Gamma.alpha", alpha, new IncludingPositiveReal(minimumAlpha), true);
-  addParameter_(p1);
-  Parameter p2("Gamma.beta", beta, new IncludingPositiveReal(minimumBeta), true);
-  addParameter_(p2);
+  addParameter_(new Parameter("Gamma.alpha", alpha, new IntervalConstraint(1, minimumAlpha, true), true));
+  addParameter_(new Parameter("Gamma.beta", beta, new IntervalConstraint(1, minimumBeta, true), true));
   ga1_ = exp(RandomTools::lnGamma(alpha_ + 1) - RandomTools::lnGamma(alpha_));
 
   intMinMax_.setLowerBound(0, true);
@@ -109,13 +107,6 @@ void GammaDiscreteDistribution::fireParameterChanged(const ParameterList& parame
 
 /******************************************************************************/
 
-Domain GammaDiscreteDistribution::getDomain() const
-{
-  return Domain(bounds_, MapTools::getKeys<double, double, AbstractDiscreteDistribution::Order>(distribution_));
-}
-
-/******************************************************************************/
-
 // Adapted from function DiscreteGamma of Yang
 
 double GammaDiscreteDistribution::qProb(double x) const
