@@ -64,6 +64,8 @@ namespace bpp
     double ga1_;
     
   public:
+    std::string getName() const {return("Gamma");}
+
     /**
      * @brief Build a new discretized gamma distribution.
      * @param n the number of categories to use.
@@ -78,7 +80,7 @@ namespace bpp
      * If @f$ alpha > 1 @f$, the minimum value of the distribution is
      * set to 1e-12, otherwise it is 0.
      */
-    GammaDiscreteDistribution(unsigned int n, double alpha = 1., double beta = 1., double minimumAlpha = 0.05, double minimumBeta = 0.05);
+    GammaDiscreteDistribution(size_t n, double alpha = 1., double beta = 1., double minimumAlpha = 0.05, double minimumBeta = 0.05);
 
     GammaDiscreteDistribution(const GammaDiscreteDistribution&);
 
@@ -88,9 +90,6 @@ namespace bpp
 
     GammaDiscreteDistribution* clone() const { return new GammaDiscreteDistribution(*this); }
 
-  
-  public:
-    Domain getDomain() const;
     void fireParameterChanged(const ParameterList & parameters);
   
     double randC() const throw (Exception)
