@@ -77,7 +77,7 @@ MixtureOfDiscreteDistributions::MixtureOfDiscreteDistributions(const vector<Disc
   double y = 1;
   for (size_t i = 0; i < size - 1; i++)
   {
-    addParameter_(Parameter("Mixture.theta" + TextTools::toString(i + 1), probas[i] / y, &Parameter::PROP_CONSTRAINT_IN));
+    addParameter_(new Parameter("Mixture.theta" + TextTools::toString(i + 1), probas[i] / y, &Parameter::PROP_CONSTRAINT_IN));
     y -= probas[i];
   }
 
@@ -89,14 +89,18 @@ MixtureOfDiscreteDistributions::MixtureOfDiscreteDistributions(const vector<Disc
 
   //  Parameters
 
-  for (size_t i = 0; i < size; i++){
-    vNestedPrefix_.push_back(TextTools::toString(i+1)+"_"+distributions[i]->getNamespace());
+  for (size_t i = 0; i < size; i++)
+  {
+    vNestedPrefix_.push_back(TextTools::toString(i + 1) + "_" + distributions[i]->getNamespace());
   }
 
   for (size_t i = 0; i < size; i++)
-    vdd_[i]->setNamespace("Mixture."+vNestedPrefix_[i]);
-  
-  for (size_t i = 0; i < size; i++){
+  {
+    vdd_[i]->setNamespace("Mixture." + vNestedPrefix_[i]);
+  }
+
+  for (size_t i = 0; i < size; i++)
+  {
     addParameters_(vdd_[i]->getParameters());
   }
 
@@ -111,27 +115,27 @@ MixtureOfDiscreteDistributions::MixtureOfDiscreteDistributions(const MixtureOfDi
   vNestedPrefix_()
 {
   for (size_t i = 0; i < mdd.vdd_.size(); i++)
-    {
-      probas_.push_back(mdd.probas_[i]);
-      vdd_.push_back(mdd.vdd_[i]->clone());
-      vNestedPrefix_.push_back(mdd.vNestedPrefix_[i]);
-    }
+  {
+    probas_.push_back(mdd.probas_[i]);
+    vdd_.push_back(mdd.vdd_[i]->clone());
+    vNestedPrefix_.push_back(mdd.vNestedPrefix_[i]);
+  }
 }
 
-MixtureOfDiscreteDistributions& MixtureOfDiscreteDistributions::operator=(const MixtureOfDiscreteDistributions& mdd) 
+MixtureOfDiscreteDistributions& MixtureOfDiscreteDistributions::operator=(const MixtureOfDiscreteDistributions& mdd)
 {
   AbstractParameterAliasable::operator=(mdd);
   AbstractDiscreteDistribution::operator=(mdd);
   vdd_.clear();
   probas_.clear();
   vNestedPrefix_.clear();
-  
+
   for (size_t i = 0; i < mdd.vdd_.size(); i++)
-    {
-      probas_.push_back(mdd.probas_[i]);
-      vdd_.push_back(mdd.vdd_[i]->clone());
-      vNestedPrefix_.push_back(mdd.vNestedPrefix_[i]);
-    }
+  {
+    probas_.push_back(mdd.probas_[i]);
+    vdd_.push_back(mdd.vdd_[i]->clone());
+    vNestedPrefix_.push_back(mdd.vNestedPrefix_[i]);
+  }
 
   return *this;
 }
@@ -139,14 +143,14 @@ MixtureOfDiscreteDistributions& MixtureOfDiscreteDistributions::operator=(const
 MixtureOfDiscreteDistributions::~MixtureOfDiscreteDistributions()
 {
   for (size_t i = 0; i < vdd_.size(); i++)
-    {
-      delete vdd_[i];
-    }
+  {
+    delete vdd_[i];
+  }
 
   vdd_.clear();
 }
 
-void MixtureOfDiscreteDistributions::setNumberOfCategories(unsigned int nbClasses)
+void MixtureOfDiscreteDistributions::setNumberOfCategories(size_t nbClasses)
 {
   for (size_t i = 0; i < vdd_.size(); i++)
   {
@@ -159,6 +163,7 @@ void MixtureOfDiscreteDistributions::setNumberOfCategories(unsigned int nbClasse
 
 void MixtureOfDiscreteDistributions::fireParameterChanged(const ParameterList& parameters)
 {
+  AbstractDiscreteDistribution::fireParameterChanged(parameters);
   size_t size = vdd_.size();
   double x = 1.0;
   for (size_t i = 0; i < size - 1; i++)
@@ -170,22 +175,8 @@ void MixtureOfDiscreteDistributions::fireParameterChanged(const ParameterList& p
   probas_[size - 1] = x;
 
 
-  // fireParameterChanged on members Distributions
-
-//  ParameterList pl;
-//  size_t pos;
-//  vector<string> v = getParameters().getParameterNames();
-//  vector<string> v2;
   for (size_t i = 0; i < size; i++)
   {
-//    pl.reset();
-//    for (size_t j = 0; j < v.size(); j++)
-//    {
-//      pos = v[j].find("Mixture." + TextTools::toString(i + 1));
-//      if (pos != string::npos)
-//        pl.addParameter(Parameter(v[j].substr(v[j].find("_", pos) + 1),
-//                                  getParameterValue(getParameterNameWithoutNamespace(v[j]))));
-//    }
     vdd_[i]->matchParametersValues(parameters);
   }
 
@@ -211,7 +202,7 @@ void MixtureOfDiscreteDistributions::updateDistribution()
   {
     vector<double> values = vdd_[i]->getCategories();
     vector<double> probas2 = vdd_[i]->getProbabilities();
-    for (unsigned int j = 0; j < values.size(); j++)
+    for (size_t j = 0; j < values.size(); j++)
     {
       distribution_[values[j]] += probas2[j] * probas_[i];
     }
@@ -222,42 +213,38 @@ void MixtureOfDiscreteDistributions::updateDistribution()
   // intMinMax_
 
   double uB, lB;
-  uB = -NumConstants::VERY_BIG;
-  lB = NumConstants::VERY_BIG;
+  uB = -NumConstants::VERY_BIG();
+  lB = NumConstants::VERY_BIG();
+
+  bool suB = true, slB = true;
 
   for (size_t i = 0; i < size; i++)
   {
-    if (vdd_[i]->getLowerBound() < lB)
+    if (vdd_[i]->getLowerBound() <= lB)
+    {
       lB = vdd_[i]->getLowerBound();
-    if (vdd_[i]->getUpperBound() > uB)
+      slB = vdd_[i]->strictLowerBound();
+    }
+    if (vdd_[i]->getUpperBound() >= uB)
+    {
       uB = vdd_[i]->getUpperBound();
+      suB = vdd_[i]->strictUpperBound();
+    }
   }
 
-  intMinMax_.setLowerBound(lB, false);
-  intMinMax_.setUpperBound(uB, false);
-}
+  intMinMax_.setLowerBound(lB, slB);
+  intMinMax_.setUpperBound(uB, suB);
 
-Domain MixtureOfDiscreteDistributions::getDomain() const
-{
-  // Compute a new arbitray bounderi:
+  // Compute midpoint bounds_:
   vector<double> values = MapTools::getKeys<double, double, AbstractDiscreteDistribution::Order>(distribution_);
-  size_t n = values.size();
-  vector<double> bounderi(n + 1);
 
-  // Fill from 1 to n-1 with midpoints:
-  for (size_t i = 1; i <= n - 1; i++)
+  bounds_.resize(numberOfCategories_ - 1);
+
+  // Fill from 0 to numberOfCategories_-1 with midpoints:
+  for (size_t i = 0; i < numberOfCategories_ - 1; i++)
   {
-    bounderi[i] = (values[i] + values[i - 1]) / 2.;
+    bounds_[i] = (values[i] + values[i + 1]) / 2.;
   }
-
-  // Fill 0 with the values[0] - (midpoint[0] - values[0]):
-  bounderi[0] = 2 * values[0] - bounderi[1];
-
-  // Fill n with values[n - 1] + (values[n - 1] - midpoint[n - 1]):
-  bounderi[n] = 2 * values[n - 1] - bounderi[n - 1];
-
-  // Build a domain and return it
-  return Domain(bounderi, values);
 }
 
 void MixtureOfDiscreteDistributions::setMedian(bool median)
@@ -323,10 +310,10 @@ void MixtureOfDiscreteDistributions::restrictToConstraint(const Constraint& c)
 void MixtureOfDiscreteDistributions::setNamespace(const string& prefix)
 {
   AbstractDiscreteDistribution::setNamespace(prefix);
-  //We also need to update the namespace of the nested distributions:
+  // We also need to update the namespace of the nested distributions:
   for (size_t i = 0; i < vdd_.size(); i++)
-    {
-      vdd_[i]->setNamespace(prefix+ vNestedPrefix_[i]);
-    }
+  {
+    vdd_[i]->setNamespace(prefix + vNestedPrefix_[i]);
+  }
 }
 
