@@ -78,7 +78,8 @@ namespace bpp
     UniformDiscreteDistribution* clone() const { return new UniformDiscreteDistribution(*this); }
   
   public:
-    Domain getDomain() const;
+    std::string getName() const {return("Uniform");}
+
     void fireParameterChanged(const ParameterList & parameters);
 
     double randC() const throw (Exception)
