@@ -169,11 +169,9 @@ namespace bpp
      * @brief Pick one element in a vector
      *
      * Pick one element randomly in a vector and return it.
-     * If you choose to make the picking without replacement the element is
-     * removed from the vector
      *
      * @param v The vector of elements.
-     * @param replace Should pick with replacement? (default: false)
+     * @param replace If set to yes, then elements are allowed to be picked more than once, and therefore can be re-"placed" in the final sample.(default: false)
      * @return On element of the vector.
      * @throw EmptyVectorException if the vector is empty.
      *
@@ -183,7 +181,7 @@ namespace bpp
     static T pickOne(std::vector<T>& v, bool replace = false) throw (EmptyVectorException<T>) {
       if (v.empty())
         throw EmptyVectorException<T>("RandomTools::pickOne: input vector is empty", &v);
-      size_t pos = static_cast<size_t>(RandomTools::giveIntRandomNumberBetweenZeroAndEntry(v.size()));
+      size_t pos = static_cast<size_t>(RandomTools::giveIntRandomNumberBetweenZeroAndEntry(static_cast<int>(v.size())));
       if (replace)
         return v[pos];
       else {
@@ -216,10 +214,10 @@ namespace bpp
     {
       if (vout.size() > vin.size() && !replace)
         throw IndexOutOfBoundsException("RandomTools::getSample: size exceeded v.size.", vout.size(), 0, vin.size());
-      std::vector<unsigned int> hat(vin.size());
-      for (unsigned int i = 0 ; i < vin.size() ; i++)
+      std::vector<size_t> hat(vin.size());
+      for (size_t i = 0 ; i < vin.size() ; i++)
         hat[i] = i;
-      for (unsigned int i = 0 ; i < vout.size() ; i++)
+      for (size_t i = 0 ; i < vout.size() ; i++)
         vout[i] = vin[pickOne(hat, replace)];
     }
 
@@ -231,6 +229,7 @@ namespace bpp
      * removed from the vector, and so is the corresponding weight
      *
      * @param v The vector of elements.
+     * @param w The vector of weight associated to the v elements.
      * @param replace Should pick with replacement? (default: false)
      * @return On element of the vector.
      * @throw EmptyVectorException if the vector is empty.
@@ -294,11 +293,11 @@ namespace bpp
     {
       if (vout.size() > vin.size() && !replace)
         throw IndexOutOfBoundsException("RandomTools::getSample (with weights): size exceeded v.size.", vout.size(), 0, vin.size());
-      std::vector<unsigned int> hat(vin.size());
-      for (unsigned int i = 0 ; i < vin.size() ; i++)
+      std::vector<size_t> hat(vin.size());
+      for (size_t i = 0 ; i < vin.size() ; i++)
         hat[i] = i;
       std::vector<double> w2(w); //non const copy
-      for (unsigned int i = 0 ; i < vout.size() ; i++)
+      for (size_t i = 0 ; i < vout.size() ; i++)
         vout[i] = vin[pickOne(hat, w2, replace)];
     }
 
@@ -312,7 +311,7 @@ namespace bpp
      * @param probs The set of intput probabilities.
      * @return A vector of int values corresponding to the output states. States are supposed to be in the same order as the input probabilities, the first state being '0'.
      */ 
-    static std::vector<unsigned int> randMultinomial(unsigned int n, const std::vector<double>& probs);
+    static std::vector<size_t> randMultinomial(size_t n, const std::vector<double>& probs);
 
     /**
      * @name Probability functions.
