@@ -60,11 +60,20 @@ typedef std::vector<std::complex<double> > Vcomplex;
 typedef std::vector<Vcomplex> VVcomplex;
 typedef std::vector<VVcomplex> VVVcomplex;
 
+typedef std::vector<std::complex<long double> > Vlcomplex;
+typedef std::vector<Vlcomplex> VVlcomplex;
+typedef std::vector<VVlcomplex> VVVlcomplex;
+
 typedef std::vector<double> Vdouble;
 typedef std::vector<Vdouble> VVdouble;
 typedef std::vector<VVdouble> VVVdouble;
 typedef std::vector<VVVdouble> VVVVdouble;
 
+typedef std::vector<long double> Vldouble;
+typedef std::vector<Vldouble> VVldouble;
+typedef std::vector<VVldouble> VVVldouble;
+typedef std::vector<VVVldouble> VVVVldouble;
+
 typedef std::vector<int> Vint;
 typedef std::vector<Vint> VVint;
 typedef std::vector<VVint> VVVint;
@@ -78,7 +87,7 @@ typedef std::vector<VVVint> VVVVint;
 template<class T>
 std::vector<T>  operator+(const std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  unsigned int size;
+  size_t size;
   if (v1.size() != v2.size())
   {
     throw DimensionException("VectorTools::operator+", v1.size(), v2.size());
@@ -88,7 +97,7 @@ std::vector<T>  operator+(const std::vector<T>& v1, const std::vector<T>& v2) th
     size = v1.size();
   }
   std::vector<T> result(size);
-  for (unsigned int i = 0; i < size; i++)
+  for (size_t i = 0; i < size; i++)
   {
     result[i] = v1[i] + v2[i];
   }
@@ -98,7 +107,7 @@ std::vector<T>  operator+(const std::vector<T>& v1, const std::vector<T>& v2) th
 template<class T>
 std::vector<T> operator-(const std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  unsigned int size;
+  size_t size;
   if (v1.size() != v2.size())
   {
     throw DimensionException("VectorTools::operator-", v1.size(), v2.size());
@@ -108,7 +117,7 @@ std::vector<T> operator-(const std::vector<T>& v1, const std::vector<T>& v2) thr
     size = v1.size();
   }
   std::vector<T> result(size);
-  for (unsigned int i = 0; i < size; i++)
+  for (size_t i = 0; i < size; i++)
   {
     result[i] = v1[i] - v2[i];
   }
@@ -118,7 +127,7 @@ std::vector<T> operator-(const std::vector<T>& v1, const std::vector<T>& v2) thr
 template<class T>
 std::vector<T> operator*(const std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  unsigned int size;
+  size_t size;
   if (v1.size() != v2.size())
   {
     throw DimensionException("VectorTools::operator*", v1.size(), v2.size());
@@ -128,7 +137,7 @@ std::vector<T> operator*(const std::vector<T>& v1, const std::vector<T>& v2) thr
     size = v1.size();
   }
   std::vector<T> result(size);
-  for (unsigned int i = 0; i < size; i++)
+  for (size_t i = 0; i < size; i++)
   {
     result[i] = v1[i] * v2[i];
   }
@@ -138,7 +147,7 @@ std::vector<T> operator*(const std::vector<T>& v1, const std::vector<T>& v2) thr
 template<class T>
 std::vector<T> operator/(const std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  unsigned int size;
+  size_t size;
   if (v1.size() != v2.size())
   {
     throw DimensionException("VectorTools::operator/", v1.size(), v2.size());
@@ -148,7 +157,7 @@ std::vector<T> operator/(const std::vector<T>& v1, const std::vector<T>& v2) thr
     size = v1.size();
   }
   std::vector<T> result(size);
-  for (unsigned int i = 0; i < size; i++)
+  for (size_t i = 0; i < size; i++)
   {
     result[i] = v1[i] / v2[i];
   }
@@ -160,7 +169,7 @@ template<class T, class C>
 std::vector<T> operator+(const std::vector<T>& v1, const C& c)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = v1[i] + c;
   }
@@ -170,7 +179,7 @@ template<class T, class C>
 std::vector<T> operator+(const C& c, const std::vector<T>& v1)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = c + v1[i];
   }
@@ -181,7 +190,7 @@ template<class T, class C>
 std::vector<T> operator-(const std::vector<T>& v1, const C& c)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = v1[i] - c;
   }
@@ -191,7 +200,7 @@ template<class T, class C>
 std::vector<T> operator-(const C& c, const std::vector<T>& v1)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = c - v1[i];
   }
@@ -202,7 +211,7 @@ template<class T, class C>
 std::vector<T> operator*(const std::vector<T>& v1, const C& c)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = v1[i] * c;
   }
@@ -212,7 +221,7 @@ template<class T, class C>
 std::vector<T> operator*(const C& c, const std::vector<T>& v1)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = c * v1[i];
   }
@@ -223,7 +232,7 @@ template<class T, class C>
 std::vector<T> operator/(const std::vector<T>& v1, const C& c)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = v1[i] / c;
   }
@@ -233,7 +242,7 @@ template<class T, class C>
 std::vector<T> operator/(const C& c, const std::vector<T>& v1)
 {
   std::vector<T> result(v1.size());
-  for (unsigned int i = 0; i < result.size(); i++)
+  for (size_t i = 0; i < result.size(); i++)
   {
     result[i] = c / v1[i];
   }
@@ -244,7 +253,7 @@ std::vector<T> operator/(const C& c, const std::vector<T>& v1)
 template<class T>
 void operator+=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] += v2[i];
   }
@@ -253,7 +262,7 @@ void operator+=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionEx
 template<class T>
 void operator-=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] -= v2[i];
   }
@@ -262,7 +271,7 @@ void operator-=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionEx
 template<class T>
 void operator*=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] *= v2[i];
   }
@@ -271,7 +280,7 @@ void operator*=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionEx
 template<class T>
 void operator/=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionException)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] /= v2[i];
   }
@@ -281,7 +290,7 @@ void operator/=(std::vector<T>& v1, const std::vector<T>& v2) throw (DimensionEx
 template<class T, class C>
 void operator+=(std::vector<T>& v1, const C& c)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] += c;
   }
@@ -290,7 +299,7 @@ void operator+=(std::vector<T>& v1, const C& c)
 template<class T, class C>
 void operator-=(std::vector<T>& v1, const C& c)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] -= c;
   }
@@ -299,7 +308,7 @@ void operator-=(std::vector<T>& v1, const C& c)
 template<class T, class C>
 void operator*=(std::vector<T>& v1, const C& c)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] *= c;
   }
@@ -308,7 +317,7 @@ void operator*=(std::vector<T>& v1, const C& c)
 template<class T, class C>
 void operator/=(std::vector<T>& v1, const C& c)
 {
-  for (unsigned int i = 0; i < v1.size(); i++)
+  for (size_t i = 0; i < v1.size(); i++)
   {
     v1[i] /= c;
   }
@@ -330,36 +339,36 @@ public:
    * @{
    */
   template<class T>
-  static void resize2(VVdouble& vv, unsigned int n1, unsigned int n2)
+  static void resize2(VVdouble& vv, size_t n1, size_t n2)
   {
     vv.resize(n1);
-    for (unsigned int i = 0; i < n1; i++) { vv[i].resize(n2); }
+    for (size_t i = 0; i < n1; i++) { vv[i].resize(n2); }
   }
 
   template<class T>
-  static void resize3(VVVdouble& vvv, unsigned int n1, unsigned int n2, unsigned int n3)
+  static void resize3(VVVdouble& vvv, size_t n1, size_t n2, size_t n3)
   {
     vvv.resize(n1);
-    for (unsigned int i = 0; i < n1; i++)
+    for (size_t i = 0; i < n1; i++)
     {
       vvv[i].resize(n2);
-      for (unsigned int j = 0; j < n2; j++)
+      for (size_t j = 0; j < n2; j++)
       {
         vvv[i][j].resize(n3);
       }
     }
   }
 
-  static void resize4(VVVVdouble& vvvv, unsigned int n1, unsigned int n2, unsigned int n3, unsigned int n4)
+  static void resize4(VVVVdouble& vvvv, size_t n1, size_t n2, size_t n3, size_t n4)
   {
     vvvv.resize(n1);
-    for (unsigned int i = 0; i < n1; i++)
+    for (size_t i = 0; i < n1; i++)
     {
       vvvv[i].resize(n2);
-      for (unsigned int j = 0; j < n2; j++)
+      for (size_t j = 0; j < n2; j++)
       {
         vvvv[i][j].resize(n3);
-        for (unsigned int k = 0; k < n3; k++)
+        for (size_t k = 0; k < n3; k++)
         {
           vvvv[i][j][k].resize(n4);
         }
@@ -422,9 +431,9 @@ public:
    * @return The position of which in v.
    */
   template<class T>
-  static unsigned int which(const std::vector<T>& v, const T& which) throw (ElementNotFoundException<T> )
+  static size_t which(const std::vector<T>& v, const T& which) throw (ElementNotFoundException<T> )
   {
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       if (v[i] == which) return i;
     }
@@ -442,10 +451,10 @@ public:
    * @return A std::vector containing the positions of which in v.
    */
   template<class T>
-  static std::vector<unsigned int> whichAll(const std::vector<T>& v, const T& which) throw (ElementNotFoundException<T> )
+  static std::vector<size_t> whichAll(const std::vector<T>& v, const T& which) throw (ElementNotFoundException<T> )
   {
-    std::vector<unsigned int> w;
-    for (unsigned int i = 0; i < v.size(); i++)
+    std::vector<size_t> w;
+    for (size_t i = 0; i < v.size(); i++)
     {
       if (v[i] == which) w.push_back(i);
     }
@@ -473,7 +482,7 @@ public:
     sort(sortedV.begin(), sortedV.end());
     std::vector<T> uniq;
     uniq.push_back(sortedV[0]);
-    for (unsigned int i = 1; i < sortedV.size(); i++)
+    for (size_t i = 1; i < sortedV.size(); i++)
     {
       if (sortedV[i] != sortedV[i - 1]) uniq.push_back(sortedV[i]);
     }
@@ -496,7 +505,7 @@ public:
     if (v.size() == 0) return true;
     std::vector<T> sortedV(v.begin(), v.end());
     sort(sortedV.begin(), sortedV.end());
-    for (unsigned int i = 1; i < sortedV.size(); i++)
+    for (size_t i = 1; i < sortedV.size(); i++)
     {
       if (sortedV[i] == sortedV[i - 1]) return false;
     }
@@ -505,16 +514,16 @@ public:
 
   /**
    * @author Laurent Gueguen
-   * @return the std::vector of the selected elements, in the order of the
-   *  required positions
    * @param v1 the std::vector of elements,
    * @param v2 the std::vector of the selected positions
+   * @return the std::vector of the selected elements, in the order of the
+   *  required positions
    */
   template<class T>
   static std::vector<T> extract(const std::vector<T>& v1, const std::vector<int>& v2)
   {
     std::vector<T> v(v2.size());
-    for (unsigned int i = 0; i < v2.size(); i++)
+    for (size_t i = 0; i < v2.size(); i++)
     {
       v[i] = v1[v2[i]];
     }
@@ -528,10 +537,10 @@ public:
    * @param v the std::vector to parse.
    */
   template<class T>
-  static std::map<T, unsigned int> countValues(const std::vector<T>& v)
+  static std::map<T, size_t> countValues(const std::vector<T>& v)
   {
-    std::map<T, unsigned int> c;
-    for (unsigned int i = 0; i < v.size(); i++)
+    std::map<T, size_t> c;
+    for (size_t i = 0; i < v.size(); i++)
     {
       c[v[i]]++;
     }
@@ -545,7 +554,7 @@ public:
    * in a given number of classes.
    *
    * @param v The std::vector to parse.
-   * @param n The expected number of clasees.
+   * @param n The expected number of classes.
    * @return a std::vector of size = n + 1 containing the breaking points.
    */
   static std::vector<double> breaks(const std::vector<double>& v, unsigned int n);
@@ -561,13 +570,13 @@ public:
    * @return The number of classes.
    */
   template<class T>
-  static unsigned int nclassScott(const std::vector<T>& v)
+  static size_t nclassScott(const std::vector<T>& v)
   {
     std::vector<T> r1 = VectorTools::range(v);
     T r = r1[1] - r1[0];
     double n = v.size();
     double h = 3.5 * VectorTools::sd<T, double>(v) * std::pow(n, -1. / 3);
-    return (unsigned int) ceil(r / h);
+    return (size_t) ceil(r / h);
   }
 
   /**
@@ -635,11 +644,11 @@ public:
   {
     T M = max(v);
     T x = std::exp(v[0] - M);
-    for (unsigned int i = 1; i < v.size(); i++)
+    for (size_t i = 1; i < v.size(); i++)
     {
       x += std::exp(v[i] - M);
     }
-    v -= M + log(x);
+    v -= M + std::log(x);
   }
 
   /**
@@ -652,7 +661,7 @@ public:
   {
     T M = max(v1);
     T x = std::exp(v1[0] - M);
-    for (unsigned int i = 1; i < v1.size(); i++)
+    for (size_t i = 1; i < v1.size(); i++)
     {
       x += std::exp(v1[i] - M);
     }
@@ -668,7 +677,7 @@ public:
   template<class T>
   static T logSumExp(const std::vector<T>& v1, const std::vector<T>& v2)
   {
-    unsigned int size;
+    size_t size;
     if (v1.size() != v2.size())
       throw DimensionException("VectorTools::logsumexp", v1.size(), v2.size());
     else
@@ -676,7 +685,7 @@ public:
 
     T M = max(v1);
     T x = v2[0] * std::exp(v1[0] - M);
-    for (unsigned int i = 1; i < size; i++)
+    for (size_t i = 1; i < size; i++)
     {
       x += v2[i] * std::exp(v1[i] - M);
     }
@@ -693,7 +702,7 @@ public:
   {
     T M = max(v1);
     T x = std::exp(v1[0] - M);
-    for (unsigned int i = 1; i < v1.size(); i++)
+    for (size_t i = 1; i < v1.size(); i++)
     {
       x += std::exp(v1[i] - M);
     }
@@ -711,7 +720,7 @@ public:
   {
     T M = max(v1);
     T x = std::exp(v1[0] - M);
-    for (unsigned int i = 1; i < v1.size(); i++)
+    for (size_t i = 1; i < v1.size(); i++)
     {
       x += std::exp(v1[i] - M);
     }
@@ -727,7 +736,7 @@ public:
   template<class T>
   static T sumExp(const std::vector<T>& v1, const std::vector<T>& v2)
   {
-    unsigned int size;
+    size_t size;
     if (v1.size() != v2.size())
       throw DimensionException("VectorTools::logsumexp", v1.size(), v2.size());
     else
@@ -735,7 +744,7 @@ public:
 
     T M = max(v1);
     T x = v2[0] * std::exp(v1[0] - M);
-    for (unsigned int i = 1; i < size; i++)
+    for (size_t i = 1; i < size; i++)
     {
       x += v2[i] * std::exp(v1[i] - M);
     }
@@ -752,14 +761,14 @@ public:
   static std::vector<double> log(const std::vector<T>& v1)
   {
     std::vector<double> v2(v1.size());
-    for (unsigned int i = 0; i < v2.size(); i++) { v2[i] = std::log(v1[i]); }
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::log(v1[i]); }
     return v2;
   }
   template<class T>
   static std::vector<double> log(const std::vector<T>& v1, double base)
   {
     std::vector<double> v2(v1.size());
-    for (unsigned int i = 0; i < v2.size(); i++) { v2[i] = std::log(v1[i]) / std::log(base); }
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::log(v1[i]) / std::log(base); }
     return v2;
   }
 
@@ -767,7 +776,7 @@ public:
   static std::vector<double> exp(const std::vector<T>& v1)
   {
     std::vector<double> v2(v1.size());
-    for (unsigned int i = 0; i < v2.size(); i++) { v2[i] = std::exp(v1[i]); }
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::exp(v1[i]); }
     return v2;
   }
 
@@ -775,7 +784,7 @@ public:
   static std::vector<double> cos(const std::vector<T>& v1)
   {
     std::vector<double> v2(v1.size());
-    for (unsigned int i = 0; i < v2.size(); i++) { v2[i] = std::cos(v1[i]); }
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::cos(v1[i]); }
     return v2;
   }
 
@@ -783,7 +792,7 @@ public:
   static std::vector<double> sin(const std::vector<T>& v1)
   {
     std::vector<double> v2(v1.size());
-    for (unsigned int i = 0; i < v2.size(); i++) { v2[i] = std::sin(v1[i]); }
+    for (size_t i = 0; i < v2.size(); i++) { v2[i] = std::sin(v1[i]); }
     return v2;
   }
 
@@ -791,7 +800,7 @@ public:
   static std::vector<double> log10(const std::vector<T>& v1)
   {
     std::vector<double> v2(v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++) { v2[i] = std::log10(v1[i]); }
+    for (size_t i = 0; i < v1.size(); i++) { v2[i] = std::log10(v1[i]); }
     return v2;
   }
 
@@ -799,7 +808,7 @@ public:
   static std::vector<T> fact(const std::vector<T>& v1)
   {
     std::vector<T> v2(v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++) { v2[i] = NumTools::fact<T>(v1[i]); }
+    for (size_t i = 0; i < v1.size(); i++) { v2[i] = NumTools::fact<T>(v1[i]); }
     return v2;
   }
 
@@ -807,7 +816,7 @@ public:
   static std::vector<T> sqr(const std::vector<T>& v1)
   {
     std::vector<T> v2(v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++) { v2[i] = NumTools::sqr<T>(v1[i]); }
+    for (size_t i = 0; i < v1.size(); i++) { v2[i] = NumTools::sqr<T>(v1[i]); }
     return v2;
   }
 
@@ -815,7 +824,7 @@ public:
   static std::vector<T> pow(const std::vector<T>& v1, T& b)
   {
     std::vector<T> v2(v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++) { v2[i] = std::pow(v1[i], b); }
+    for (size_t i = 0; i < v1.size(); i++) { v2[i] = std::pow(v1[i], b); }
     return v2;
   }
   /** @} */
@@ -830,7 +839,7 @@ public:
   static std::string paste(const std::vector<T>& v, const std::string& delim = " ")
   {
     std::ostringstream out;
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       out << v[i];
       if (i < v.size() - 1)
@@ -848,7 +857,7 @@ public:
   template<class T>
   static void print(const std::vector<T>& v1, OutputStream& out = * ApplicationTools::message, const std::string& delim = " ")
   {
-    for (unsigned int i = 0; i < v1.size(); i++)
+    for (size_t i = 0; i < v1.size(); i++)
     {
       out << v1[i];
       if (i < v1.size() - 1)
@@ -857,6 +866,26 @@ public:
     out.endLine();
   }
 
+  /**
+   * @brief Print a std::vector to a stream in R format
+   * @param v1 A std::vector.
+   * @param variableName the variable name (default "x").
+   * @param out A stream (default cout).
+   */
+  template<class T>
+  static void printForR(const std::vector<T>& v1, std::string variableName = "x", std::ostream& out = std::cout)
+  {
+    out.precision(12);
+    out << variableName << "<-c(";
+    for (size_t i = 0; i < v1.size(); i++)
+    {
+      out << v1[i];
+      if (i < v1.size() - 1)
+        out << ", ";
+    }
+    out << ")" << std::endl;
+  }
+
   /**
    * @return The scalar product of two std::vectors.
    * @param v1 First std::vector.
@@ -1164,7 +1193,7 @@ public:
    * throw EmptyVectorException If the input std::vector is empty.
    */
   template<class T>
-  static std::vector<T> range(const std::vector<T>& v) throw (EmptyVectorException<T>)
+  static std::vector<T> range(const std::vector<T>& v) throw (EmptyVectorException<T> )
   {
     if (v.size() == 0)
       throw EmptyVectorException<T>("VectorTools::range()", &v);
@@ -1179,11 +1208,13 @@ public:
   }
 
 private:
-  template<class T> class order_Cmp_ {
+  template<class T> class order_Cmp_
+  {
     const std::vector<T>& values_;
-  public:
-      order_Cmp_(const std::vector<T> &v) : values_(v) {}
-      bool operator()(size_t a, size_t b) { return values_[a] < values_[b]; }
+
+public:
+    order_Cmp_(const std::vector<T>& v) : values_(v) {}
+    bool operator()(size_t a, size_t b) { return values_[a] < values_[b]; }
   };
 
 public:
@@ -1197,14 +1228,16 @@ public:
    * throw EmptyVectorException If the input std::vector is empty.
    */
   template<class T>
-  static std::vector<size_t> order(const std::vector<T>& v) throw (EmptyVectorException<T>)
+  static std::vector<size_t> order(const std::vector<T>& v) throw (EmptyVectorException<T> )
   {
     if (v.size() == 0)
       throw EmptyVectorException<T>("VectorTools::sort()", &v);
-    //Private inner class:
+    // Private inner class:
     std::vector<size_t> index(v.size());
     for (size_t i = 0; i < index.size(); ++i)
+    {
       index[i] = i;
+    }
     sort(index.begin(), index.end(), order_Cmp_<T>(v));
     return index;
   }
@@ -1269,7 +1302,7 @@ public:
     if (v1.size() == 0) return med;
     if (v1.size() == 1) return v1[0];
     sort(v1.begin(), v1.end());
-    unsigned int i = v1.size() / 2;
+    size_t i = v1.size() / 2;
     if (v1.size() % 2 == 0)
     {
       // Vector size is pair
@@ -1294,7 +1327,7 @@ public:
   {
     OutputType m = mean<InputType, OutputType>(v1);
     std::vector<OutputType> v(v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++)
+    for (size_t i = 0; i < v1.size(); i++)
     {
       v[i] = (OutputType)v1[i] - m;
     }
@@ -1313,7 +1346,7 @@ public:
   {
     OutputType m = mean<InputType, OutputType>(v1, w, normalizeWeights);
     std::vector<OutputType> v(v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++)
+    for (size_t i = 0; i < v1.size(); i++)
     {
       v[i] = (OutputType)v1[i] - m;
     }
@@ -1481,10 +1514,10 @@ public:
    * @param base The base of the logarithm to use.
    */
   template<class InputType, class OutputType>
-  static double shannon(const std::vector<InputType>& v, double base = 2.7182818)
+  static OutputType shannon(const std::vector<InputType>& v, double base = 2.7182818)
   {
     OutputType s = 0;
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       if (v[i] > 0) s += static_cast<OutputType>(v[i] * std::log(v[i]) / std::log(base));
     }
@@ -1506,10 +1539,10 @@ public:
    * @param base The base of the logarithm to use.
    */
   template<class InputType, class OutputType>
-  static double shannonDiscrete(const std::vector<InputType>& v, double base = 2.7182818)
+  static OutputType shannonDiscrete(const std::vector<InputType>& v, double base = 2.7182818)
   {
     std::map<InputType, double> counts;
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       counts[v[i]]++;
     }
@@ -1538,14 +1571,14 @@ public:
    * @throw DimensionException if the two vectors do not have the same lengths.
    */
   template<class InputType, class OutputType>
-  static double miDiscrete(const std::vector<InputType>& v1, const std::vector<InputType>& v2, double base = 2.7182818) throw (DimensionException)
+  static OutputType miDiscrete(const std::vector<InputType>& v1, const std::vector<InputType>& v2, double base = 2.7182818) throw (DimensionException)
   {
     if (v1.size() != v2.size())
       throw DimensionException("VectorTools::miDiscrete. The two samples must have the same length.", v2.size(), v1.size());
     std::map<InputType, double> counts1;
     std::map<InputType, double> counts2;
     std::map<InputType, std::map<InputType, double> > counts12;
-    for (unsigned int i = 0; i < v1.size(); i++)
+    for (size_t i = 0; i < v1.size(); i++)
     {
       counts1[v1[i]]++;
       counts2[v2[i]]++;
@@ -1579,17 +1612,17 @@ public:
    * @param base The base of the logarithm to use.
    */
   template<class InputType, class OutputType>
-  static double shannonContinuous(const std::vector<InputType>& v, double base = 2.7182818)
+  static OutputType shannonContinuous(const std::vector<InputType>& v, double base = 2.7182818)
   {
     LinearMatrix<InputType> m(1, v.size());
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       m(0, i) = v[i];
     }
     AdaptiveKernelDensityEstimation kd(m);
     OutputType s = 0;
     std::vector<double> x(1);
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       x[0] = static_cast<double>(v[i]);
       s += static_cast<OutputType>(std::log(kd.kDensity(x)) / std::log(base));
@@ -1617,14 +1650,14 @@ public:
    * @throw DimensionException if the two vectors do not have the same lengths.
    */
   template<class InputType, class OutputType>
-  static double miContinuous(const std::vector<InputType>& v1, const std::vector<InputType>& v2, double base = 2.7182818) throw (DimensionException)
+  static OutputType miContinuous(const std::vector<InputType>& v1, const std::vector<InputType>& v2, double base = 2.7182818) throw (DimensionException)
   {
     if (v1.size() != v2.size())
       throw DimensionException("VectorTools::miContinuous. The two samples must have the same length.", v2.size(), v1.size());
     LinearMatrix<InputType> m1(1, v1.size());
     LinearMatrix<InputType> m2(1, v2.size());
     LinearMatrix<InputType> m12(2, v1.size());
-    for (unsigned int i = 0; i < v1.size(); i++)
+    for (size_t i = 0; i < v1.size(); i++)
     {
       m1(0, i) = m12(0, i) = v1[i];
       m2(0, i) = m12(1, i) = v2[i];
@@ -1636,7 +1669,7 @@ public:
     std::vector<double> x1(1);
     std::vector<double> x2(1);
     std::vector<double> x12(2);
-    for (unsigned int i = 0; i < v1.size(); i++)
+    for (size_t i = 0; i < v1.size(); i++)
     {
       x1[0] = x12[0] = static_cast<double>(v1[i]);
       x2[0] = x12[1] = static_cast<double>(v2[i]);
@@ -1686,7 +1719,7 @@ public:
   template<class T>
   static bool contains(const std::vector<T>& vec, T el)
   {
-    for (unsigned int i = 0; i < vec.size(); i++)
+    for (size_t i = 0; i < vec.size(); i++)
     {
       if (vec[i] == el) return true;
     }
@@ -1706,8 +1739,8 @@ public:
   {
     std::sort(v1.begin(), v1.end());
     std::sort(v2.begin(), v2.end());
-    unsigned int j = 0;
-    for (unsigned int i = 0; i < v2.size(); i++)
+    size_t j = 0;
+    for (size_t i = 0; i < v2.size(); i++)
     {
       if (i > 0 && v2[i] == v2[i - 1]) continue;
       while (j < v1.size() - 1 && v1[j] < v2[i]) j++;
@@ -1726,7 +1759,7 @@ public:
   static std::vector<T> vectorUnion(const std::vector<T>& vec1, const std::vector<T>& vec2)
   {
     std::vector<T> unionEl = vec1;
-    for (unsigned int j = 0; j < vec2.size(); j++)
+    for (size_t j = 0; j < vec2.size(); j++)
     {
       if (!contains(unionEl, vec2[j]))
         unionEl.push_back(vec2[j]);
@@ -1743,9 +1776,9 @@ public:
   static std::vector<T> vectorUnion(const std::vector< std::vector<T> >& vecElementL)
   {
     std::vector<T> unionEl;
-    for (unsigned int i = 0; i < vecElementL.size(); i++)
+    for (size_t i = 0; i < vecElementL.size(); i++)
     {
-      for (unsigned int j = 0; j < vecElementL[i].size(); j++)
+      for (size_t j = 0; j < vecElementL[i].size(); j++)
       {
         if (!contains(unionEl, vecElementL[i][j]))
           unionEl.push_back(vecElementL[i][j]);
@@ -1763,7 +1796,7 @@ public:
   static std::vector<T> vectorIntersection(const std::vector<T>& vec1, const std::vector<T>& vec2)
   {
     std::vector<T> interEl;
-    for (unsigned int i = 0; i < vec1.size(); i++)
+    for (size_t i = 0; i < vec1.size(); i++)
     {
       if (contains(vec2, vec1[i])) interEl.push_back(vec1[i]);
     }
@@ -1780,10 +1813,10 @@ public:
     if (vecElementL.size() == 1) return vecElementL[0];
     std::vector<T> interEl;
     if (vecElementL.size() == 0) return interEl;
-    for (unsigned int i = 0; i < vecElementL[0].size(); i++)
+    for (size_t i = 0; i < vecElementL[0].size(); i++)
     {
       bool test = true;
-      for (unsigned int j = 1; test && j < vecElementL.size(); j++)
+      for (size_t j = 1; test && j < vecElementL.size(); j++)
       {
         if (!contains(vecElementL[j], vecElementL[0][i])) test = false;
       }
@@ -1801,7 +1834,7 @@ public:
   static void append(std::vector<T>& vec1, const std::vector<T>& vec2)
   {
     vec1.insert(vec1.end(), vec2.begin(), vec2.end());
-    // for(unsigned int i = 0; i < vec2.size(); i++)
+    // for(size_t i = 0; i < vec2.size(); i++)
     // {
     //  vec1.push_back(vec2[i]);
     // }
@@ -1829,7 +1862,7 @@ public:
     if (vecElementL.size() == 1) return vecElementL[0];
     std::vector<T> v;
     if (vecElementL.size() == 0) return v;
-    for (unsigned int i = 0; i < vecElementL[0].size(); i++)
+    for (size_t i = 0; i < vecElementL[0].size(); i++)
     {
       v.push_back(vecElementL[0][i]);
     }
@@ -1844,7 +1877,7 @@ public:
   template<class T>
   static void extend(std::vector<T>& vec1, const std::vector<T>& vec2)
   {
-    for (unsigned int i = 0; i < vec2.size(); i++)
+    for (size_t i = 0; i < vec2.size(); i++)
     {
       if (!contains(vec1, vec2[i]))
         vec1.push_back(vec2[i]);
@@ -1857,13 +1890,13 @@ public:
    * @param n the number of repetitions
    */
   template<class T>
-  static std::vector<T> rep(const std::vector<T>& vec, unsigned int n)
+  static std::vector<T> rep(const std::vector<T>& vec, size_t n)
   {
     if (n == 1) return vec;
     std::vector<T> v;
     if (n == 0) return v;
     v.resize(vec.size() * n);
-    for (unsigned int i = 0; i < v.size(); i++)
+    for (size_t i = 0; i < v.size(); i++)
     {
       v[i] = vec[i % vec.size()];
     }
@@ -1885,8 +1918,8 @@ public:
     if (v2.size() == 0) append(v3, v1);
     std::sort(v1.begin(), v1.end());
     std::sort(v2.begin(), v2.end());
-    unsigned int j = 0;
-    for (unsigned int i = 0; i < v1.size(); i++)
+    size_t j = 0;
+    for (size_t i = 0; i < v1.size(); i++)
     {
       if (i > 0 && v1[i] == v1[i - 1]) continue;
       while (j < v2.size() - 1 && v2[j] < v1[i]) j++;
