@@ -46,11 +46,11 @@ knowledge of the CeCILL license and that you accept its terms.
 using namespace bpp;
 using namespace std;
 
-void KeyvalTools::singleKeyval(const std::string& desc, std::string& key, std::string& val) throw (KeyvalException)
+void KeyvalTools::singleKeyval(const std::string& desc, std::string& key, std::string& val, const std::string& split) throw (KeyvalException)
 {
-  string::size_type i = desc.find("=");
+  string::size_type i = desc.find(split);
   if (i == string::npos)
-    throw KeyvalException("Bad syntax! keyval should be of the form 'key=value', found '" + desc + "'.");
+    throw KeyvalException("Bad syntax! keyval should be of the form 'key" + split + "=value', found '" + desc + "'.");
   key = desc.substr(0, i);
   val = desc.substr(i+1);
 }
@@ -109,7 +109,7 @@ void KeyvalTools::parseProcedure(const std::string& desc, std::string& name, std
   if (begin == string::npos && end != string::npos)
     throw KeyvalException("Bad keyval procedure, missing closing parenthesis.");
   
-  if(!TextTools::isEmpty(desc.substr(end + 1)))
+  if (!TextTools::isEmpty(desc.substr(end + 1)))
     throw KeyvalException("Bad keyval procedure, extra characters after closing parenthesis: " + desc.substr(end + 1));
   //Get the procedure name (without leading spaces):
   name = TextTools::removeFirstWhiteSpaces(desc.substr(0, begin));
