@@ -64,7 +64,7 @@ class StringTokenizer
     std::deque<std::string> splits_;
 		
 		/** @brief the current position in the token list. */
-		unsigned int currentPosition_;
+		size_t currentPosition_;
 
 	public:
 		
@@ -106,7 +106,7 @@ class StringTokenizer
 		 *
 		 * @return the number of tokens available.
 		 */
-		unsigned int numberOfRemainingTokens() const { return tokens_.size() - currentPosition_; }
+		size_t numberOfRemainingTokens() const { return tokens_.size() - currentPosition_; }
 
 		/**
 		 * @brief Get a particular token.
@@ -116,7 +116,7 @@ class StringTokenizer
 		 * @param pos The index of the token.
 		 * @return the token at position 'pos'.
 		 */
-    const std::string& getToken(unsigned int pos) const { return tokens_[pos]; }
+    const std::string& getToken(size_t pos) const { return tokens_[pos]; }
 
 		/**
 		 * @brief Retrieve all tokens.
