@@ -65,9 +65,9 @@ bool TextTools::isEmpty(const std::string& s)
 std::string TextTools::toUpper(const std::string& s)
 {
   string result = "";
-  for (unsigned int i = 0; i < s.size(); i++)
+  for (size_t i = 0; i < s.size(); i++)
   {
-    result += toupper(s[i]);
+    result += static_cast<char>(toupper(static_cast<int>(s[i])));
   }
   return result;
 }
@@ -77,9 +77,9 @@ std::string TextTools::toUpper(const std::string& s)
 std::string TextTools::toLower(const std::string& s)
 {
   string result = "";
-  for (unsigned int i = 0; i < s.size(); i++)
+  for (size_t i = 0; i < s.size(); i++)
   {
-    result += tolower(s[i]);
+    result += static_cast<char>(tolower(static_cast<int>(s[i])));
   }
   return result;
 }
@@ -213,9 +213,10 @@ bool TextTools::isDecimalNumber(char c)
 
 /******************************************************************************/
 
-bool TextTools::isDecimalNumber(const std::string& s, char dec)
+bool TextTools::isDecimalNumber(const std::string& s, char dec, char scientificNotation)
 {
   size_t sepCount = 0;
+  size_t sciCount = 0;
   size_t i = 0;
   if (s[0] == '-') i = 1;
   for (; i < s.size(); ++i)
@@ -223,9 +224,16 @@ bool TextTools::isDecimalNumber(const std::string& s, char dec)
     char c = s[i];
     if (c == dec)
       sepCount++;
-    else if (!isDecimalNumber(c))
+    else if (c == scientificNotation) {
+      sciCount++;
+      if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
+      c = s[i + 1];
+      if (c == '-') i++;
+      if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
+      if (sepCount == 0) sepCount = 1; //We do not want any dec in the exponent.
+    } else if (!isDecimalNumber(c))
       return false;
-    if (sepCount > 1)
+    if (sepCount > 1 || sciCount > 1)
       return false;
   }
   return true;
@@ -233,14 +241,22 @@ bool TextTools::isDecimalNumber(const std::string& s, char dec)
 
 /******************************************************************************/
 
-bool TextTools::isDecimalInteger(const std::string& s)
+bool TextTools::isDecimalInteger(const std::string& s, char scientificNotation)
 {
+  size_t sciCount = 0;
   size_t i = 0;
   if (s[0] == '-') i = 1;
   for (; i < s.size(); ++i)
   {
     char c = s[i];
-    if (!isDecimalNumber(c))
+    if (c == scientificNotation) {
+      sciCount++;
+      if (i == s.size() - 1) return false; //Must be sthg after scientific notation.
+      c = s[i + 1];
+      if (c == '-') return false; //Not an integer then!
+    } else if (!isDecimalNumber(c))
+      return false;
+    if (sciCount > 1)
       return false;
   }
   return true;
@@ -275,8 +291,9 @@ std::string TextTools::toString(double d, int precision)
 
 /******************************************************************************/
 
-int TextTools::toInt(const std::string& s)
+int TextTools::toInt(const std::string& s) throw (Exception)
 {
+  if (!isDecimalInteger(s)) throw Exception("TextTools::toInt(). Invalid number specification: " + s);
   istringstream iss(s);
   int i;
   iss >> i;
@@ -285,8 +302,9 @@ int TextTools::toInt(const std::string& s)
 
 /******************************************************************************/
 
-double TextTools::toDouble(const std::string& s)
+double TextTools::toDouble(const std::string& s) throw (Exception)
 {
+  if (!isDecimalNumber(s)) throw Exception("TextTools::toDouble(). Invalid number specification: " + s);
   istringstream iss(s);
   double d;
   iss >> d;
@@ -295,7 +313,7 @@ double TextTools::toDouble(const std::string& s)
 
 /******************************************************************************/
 
-std::string TextTools::resizeRight(const std::string& s, unsigned int newSize, char fill)
+std::string TextTools::resizeRight(const std::string& s, size_t newSize, char fill)
 {
   if (s.size() > newSize)
     return s.substr(0, newSize);
@@ -305,7 +323,7 @@ std::string TextTools::resizeRight(const std::string& s, unsigned int newSize, c
 
 /******************************************************************************/
 
-std::string TextTools::resizeLeft(const std::string& s, unsigned int newSize, char fill)
+std::string TextTools::resizeLeft(const std::string& s, size_t newSize, char fill)
 {
   if (s.size() > newSize)
     return s.substr(s.size() - newSize);
@@ -315,7 +333,7 @@ std::string TextTools::resizeLeft(const std::string& s, unsigned int newSize, ch
 
 /******************************************************************************/
 
-std::vector<std::string> TextTools::split(const std::string& s, unsigned int n)
+std::vector<std::string> TextTools::split(const std::string& s, size_t n)
 {
   vector<string> v;
   string tmp = s;
@@ -367,22 +385,24 @@ throw (Exception)
 {
   string t = "";
   int blockCount = 0;
-  int begPos = 0;
-  for (unsigned int i = 0; i < s.size(); i++)
+  size_t begPos = 0;
+  for (size_t i = 0; i < s.size(); i++)
   {
     char current = s[i];
     if (current == blockBeginning)
     {
       bool except = false;
-      for (unsigned int j = 0; j < exceptionsBeginning.size(); j++)
+      for (size_t j = 0; j < exceptionsBeginning.size(); j++)
       {
-        int pos = exceptionsBeginning[j].find(blockBeginning);
-        int left = i - pos;
-        int right = i + exceptionsBeginning[j].length() - pos;
-        if ((left > 0 ) &&  (right < (int)(s.length()) - 1 ) && (hasSubstring (s.substr(left, right), exceptionsBeginning[j])) )
-        {
-          except = true;
-          break;
+        size_t pos = exceptionsBeginning[j].find(blockBeginning);
+        if (pos != string::npos) {
+          size_t left = i - pos;
+          size_t right = i + exceptionsBeginning[j].length() - pos;
+          if ((right < s.length() - 1) && (hasSubstring (s.substr(left, right), exceptionsBeginning[j])))
+          {
+            except = true;
+            break;
+          }
         }
       }
       if (!except)
@@ -393,14 +413,16 @@ throw (Exception)
     }
     else if ( (current == blockEnding) && (blockCount > 0) )
     {
-      for (unsigned int j = 0; j < exceptionsEnding.size(); j++)
+      for (size_t j = 0; j < exceptionsEnding.size(); j++)
       {
-        int pos = exceptionsEnding[j].find(blockEnding);
-        int left = i - pos;
-        int right = i + exceptionsEnding[j].length() - pos;
-        if ((left > 0 ) &&  (right < (int)(s.length()) - 1 ) && (hasSubstring (s.substr(left, right), exceptionsEnding[j])) )
-        {
-          break;
+        size_t pos = exceptionsEnding[j].find(blockEnding);
+        if (pos != string::npos) {
+          size_t left = i - pos;
+          size_t right = i + exceptionsEnding[j].length() - pos;
+          if ((right < s.length() - 1 ) && (hasSubstring (s.substr(left, right), exceptionsEnding[j])))
+          {
+            break;
+          }
         }
       }
       blockCount--;
@@ -486,3 +508,18 @@ bool TextTools::hasSubstring(const std::string& s, const std::string& pattern)
 
 /******************************************************************************/
 
+void TextTools::replaceAll(std::string& target, const std::string& query, const std::string& replacement)
+{
+  if (query.empty())
+    return;
+  size_t pos = 0;
+  while (pos != string::npos) {
+    pos = target.find(query, pos);
+    target.replace(pos, query.length(), replacement);
+    pos += replacement.length(); //We prevent recursivity!
+  
+  }
+}
+
+/******************************************************************************/
+
