@@ -165,18 +165,20 @@ namespace bpp
        * NB: for now, this parser will not recognize thousands delimiters, and not the scientific notation neither.
        * @param s The string to parse.
        * @param dec The decimal separator.
+       * @param scientificNotation character to use for scientific notation (typically 'e' or 'E').
        * @return true if the given string is the representation of a decimal number.
        */
-      static bool isDecimalNumber(const std::string& s, char dec = '.');
+      static bool isDecimalNumber(const std::string& s, char dec = '.', char scientificNotation = 'e');
 
       /**
        * @brief Tell is a given character string describes a decimal integer.
        *
        * NB: for now, this parser will not recognize thousands delimiters, and not the scientific notation neither.
        * @param s The string to parse.
+       * @param scientificNotation character to use for scientific notation (typically 'e' or 'E').
        * @return true if the given string is the representation of a decimal integer.
        */
-      static bool isDecimalInteger(const std::string& s);
+      static bool isDecimalInteger(const std::string& s, char scientificNotation = 'e');
 
       /**
        * @brief General template method to convert to a string.
@@ -250,16 +252,18 @@ namespace bpp
        *
        * @param s The string to parse.
        * @return The integer corresponding to s.
+       * @throw Exception if the string does not specify a valid number.
        */
-      static int toInt(const std::string& s);
+      static int toInt(const std::string& s) throw (Exception);
 
       /**
        * @brief Convert from string to double.
        *
        * @param s The string to parse.
        * @return The double corresponding to s.
+       * @throw Exception if the string does not specify a valid number.
        */
-      static double toDouble(const std::string& s);
+      static double toDouble(const std::string& s) throw (Exception);
 
       /**
        * @brief Template to string conversion.
@@ -285,7 +289,7 @@ namespace bpp
        * @param fill    The character to use to fill the string id length < newSize.
        * @return A string of size newsize which is a copy from the left of s.
        */
-      static std::string resizeRight(const std::string& s, unsigned int newSize, char fill = ' ');
+      static std::string resizeRight(const std::string& s, size_t newSize, char fill = ' ');
 
       /**
        * @brief Send a string of size 'newSize', which is a copy of 's' truncated or
@@ -296,7 +300,7 @@ namespace bpp
        * @param fill    The character to use to fill the string id length < newSize.
        * @return A string of size newsize which is a copy from the right of s.
        */
-      static std::string resizeLeft(const std::string& s, unsigned int newSize, char fill = ' ');
+      static std::string resizeLeft(const std::string& s, size_t newSize, char fill = ' ');
 
       /**
        * @brief Split a string into parts of size 'n'.
@@ -307,7 +311,7 @@ namespace bpp
        * @param n The number of tokens.
        * @return A vector of strings with all tokens.
        */
-      static std::vector<std::string> split(const std::string& s, unsigned int n);
+      static std::vector<std::string> split(const std::string& s, size_t n);
 
       /**
        * @brief Remove substrings from a string.
@@ -342,8 +346,8 @@ namespace bpp
        * @return The string with all blocks removed.
        * @throw Exception If some blocks are not well formed.
        */
-  static std::string removeSubstrings(const std::string& s, char blockBeginning, char blockEnding, std::vector<std::string>& exceptionsBeginning, std::vector<std::string>& exceptionsEnding)
-       throw (Exception);
+      static std::string removeSubstrings(const std::string& s, char blockBeginning, char blockEnding, std::vector<std::string>& exceptionsBeginning, std::vector<std::string>& exceptionsEnding)
+        throw (Exception);
   
       /**
        * @brief Remove all occurences of a character in a string.
@@ -390,6 +394,15 @@ namespace bpp
        */
       static bool hasSubstring(const std::string& s, const std::string& pattern);
 
+      /**
+       * @brief Replacement of all non-overlapping occurrences of a certain motif in a string.
+       *
+       * @param target String to be modified
+       * @param query The motif to look for
+       * @param replacement The replacement string
+       */
+      static void replaceAll(std::string& target, const std::string& query, const std::string& replacement);
+     
   };
 
 } //end of namespace bpp.
